from _typeshed import Incomplete

INET_E_USE_DEFAULT_PROTOCOLHANDLER: int
INET_E_USE_DEFAULT_SETTING: int
INET_E_DEFAULT_ACTION: int
INET_E_QUERYOPTION_UNKNOWN: int
INET_E_REDIRECTING: int
INET_E_INVALID_URL: int
INET_E_NO_SESSION: int
INET_E_CANNOT_CONNECT: int
INET_E_RESOURCE_NOT_FOUND: int
INET_E_OBJECT_NOT_FOUND: int
INET_E_DATA_NOT_AVAILABLE: int
INET_E_DOWNLOAD_FAILURE: int
INET_E_AUTHENTICATION_REQUIRED: int
INET_E_NO_VALID_MEDIA: int
INET_E_CONNECTION_TIMEOUT: int
INET_E_INVALID_REQUEST: int
INET_E_UNKNOWN_PROTOCOL: int
INET_E_SECURITY_PROBLEM: int
INET_E_CANNOT_LOAD_DATA: int
INET_E_CANNOT_INSTANTIATE_OBJECT: int
INET_E_INVALID_CERTIFICATE: int
INET_E_REDIRECT_FAILED: int
INET_E_REDIRECT_TO_DIR: int
INET_E_CANNOT_LOCK_REQUEST: int
INET_E_USE_EXTEND_BINDING: int
INET_E_TERMINATED_BIND: int
INET_E_CODE_DOWNLOAD_DECLINED: int
INET_E_RESULT_DISPATCHED: int
INET_E_CANNOT_REPLACE_SFP_FILE: int
INET_E_CODE_INSTALL_SUPPRESSED: int
INET_E_CODE_INSTALL_BLOCKED_BY_HASH_POLICY: int
MKSYS_URLMONIKER: int
URL_MK_LEGACY: int
URL_MK_UNIFORM: int
URL_MK_NO_CANONICALIZE: int
FIEF_FLAG_FORCE_JITUI: int
FIEF_FLAG_PEEK: int
FIEF_FLAG_SKIP_INSTALLED_VERSION_CHECK: int
FMFD_DEFAULT: int
FMFD_URLASFILENAME: int
FMFD_ENABLEMIMESNIFFING: int
FMFD_IGNOREMIMETEXTPLAIN: int
URLMON_OPTION_USERAGENT: int
URLMON_OPTION_USERAGENT_REFRESH: int
URLMON_OPTION_URL_ENCODING: int
URLMON_OPTION_USE_BINDSTRINGCREDS: int
URLMON_OPTION_USE_BROWSERAPPSDOCUMENTS: int
CF_NULL: int
Uri_CREATE_ALLOW_RELATIVE: int
Uri_CREATE_ALLOW_IMPLICIT_WILDCARD_SCHEME: int
Uri_CREATE_ALLOW_IMPLICIT_FILE_SCHEME: int
Uri_CREATE_NOFRAG: int
Uri_CREATE_NO_CANONICALIZE: int
Uri_CREATE_CANONICALIZE: int
Uri_CREATE_FILE_USE_DOS_PATH: int
Uri_CREATE_DECODE_EXTRA_INFO: int
Uri_CREATE_NO_DECODE_EXTRA_INFO: int
Uri_CREATE_CRACK_UNKNOWN_SCHEMES: int
Uri_CREATE_NO_CRACK_UNKNOWN_SCHEMES: int
Uri_CREATE_PRE_PROCESS_HTML_URI: int
Uri_CREATE_NO_PRE_PROCESS_HTML_URI: int
Uri_CREATE_IE_SETTINGS: int
Uri_CREATE_NO_IE_SETTINGS: int
Uri_CREATE_NO_ENCODE_FORBIDDEN_CHARACTERS: int
Uri_DISPLAY_NO_FRAGMENT: int
Uri_PUNYCODE_IDN_HOST: int
Uri_DISPLAY_IDN_HOST: int
Uri_ENCODING_USER_INFO_AND_PATH_IS_PERCENT_ENCODED_UTF8: int
Uri_ENCODING_USER_INFO_AND_PATH_IS_CP: int
Uri_ENCODING_HOST_IS_IDN: int
Uri_ENCODING_HOST_IS_PERCENT_ENCODED_UTF8: int
Uri_ENCODING_HOST_IS_PERCENT_ENCODED_CP: int
Uri_ENCODING_QUERY_AND_FRAGMENT_IS_PERCENT_ENCODED_UTF8: int
Uri_ENCODING_QUERY_AND_FRAGMENT_IS_CP: int
Uri_ENCODING_RFC: Incomplete
UriBuilder_USE_ORIGINAL_FLAGS: int
WININETINFO_OPTION_LOCK_HANDLE: int
URLOSTRM_USECACHEDCOPY_ONLY: int
URLOSTRM_USECACHEDCOPY: int
URLOSTRM_GETNEWESTVERSION: int
SET_FEATURE_ON_THREAD: int
SET_FEATURE_ON_PROCESS: int
SET_FEATURE_IN_REGISTRY: int
SET_FEATURE_ON_THREAD_LOCALMACHINE: int
SET_FEATURE_ON_THREAD_INTRANET: int
SET_FEATURE_ON_THREAD_TRUSTED: int
SET_FEATURE_ON_THREAD_INTERNET: int
SET_FEATURE_ON_THREAD_RESTRICTED: int
GET_FEATURE_FROM_THREAD: int
GET_FEATURE_FROM_PROCESS: int
GET_FEATURE_FROM_REGISTRY: int
GET_FEATURE_FROM_THREAD_LOCALMACHINE: int
GET_FEATURE_FROM_THREAD_INTRANET: int
GET_FEATURE_FROM_THREAD_TRUSTED: int
GET_FEATURE_FROM_THREAD_INTERNET: int
GET_FEATURE_FROM_THREAD_RESTRICTED: int
PROTOCOLFLAG_NO_PICS_CHECK: int
MUTZ_NOSAVEDFILECHECK: int
MUTZ_ISFILE: int
MUTZ_ACCEPT_WILDCARD_SCHEME: int
MUTZ_ENFORCERESTRICTED: int
MUTZ_RESERVED: int
MUTZ_REQUIRESAVEDFILECHECK: int
MUTZ_DONT_UNESCAPE: int
MUTZ_DONT_USE_CACHE: int
MUTZ_FORCE_INTRANET_FLAGS: int
MUTZ_IGNORE_ZONE_MAPPINGS: int
MAX_SIZE_SECURITY_ID: int
URLACTION_MIN: int
URLACTION_DOWNLOAD_MIN: int
URLACTION_DOWNLOAD_SIGNED_ACTIVEX: int
URLACTION_DOWNLOAD_UNSIGNED_ACTIVEX: int
URLACTION_DOWNLOAD_CURR_MAX: int
URLACTION_DOWNLOAD_MAX: int
URLACTION_ACTIVEX_MIN: int
URLACTION_ACTIVEX_RUN: int
URLPOLICY_ACTIVEX_CHECK_LIST: int
URLACTION_ACTIVEX_OVERRIDE_OBJECT_SAFETY: int
URLACTION_ACTIVEX_OVERRIDE_DATA_SAFETY: int
URLACTION_ACTIVEX_OVERRIDE_SCRIPT_SAFETY: int
URLACTION_SCRIPT_OVERRIDE_SAFETY: int
URLACTION_ACTIVEX_CONFIRM_NOOBJECTSAFETY: int
URLACTION_ACTIVEX_TREATASUNTRUSTED: int
URLACTION_ACTIVEX_NO_WEBOC_SCRIPT: int
URLACTION_ACTIVEX_OVERRIDE_REPURPOSEDETECTION: int
URLACTION_ACTIVEX_OVERRIDE_OPTIN: int
URLACTION_ACTIVEX_SCRIPTLET_RUN: int
URLACTION_ACTIVEX_DYNSRC_VIDEO_AND_ANIMATION: int
URLACTION_ACTIVEX_CURR_MAX: int
URLACTION_ACTIVEX_MAX: int
URLACTION_SCRIPT_MIN: int
URLACTION_SCRIPT_RUN: int
URLACTION_SCRIPT_JAVA_USE: int
URLACTION_SCRIPT_SAFE_ACTIVEX: int
URLACTION_CROSS_DOMAIN_DATA: int
URLACTION_SCRIPT_PASTE: int
URLACTION_ALLOW_XDOMAIN_SUBFRAME_RESIZE: int
URLACTION_SCRIPT_CURR_MAX: int
URLACTION_SCRIPT_MAX: int
URLACTION_HTML_MIN: int
URLACTION_HTML_SUBMIT_FORMS: int
URLACTION_HTML_SUBMIT_FORMS_FROM: int
URLACTION_HTML_SUBMIT_FORMS_TO: int
URLACTION_HTML_FONT_DOWNLOAD: int
URLACTION_HTML_JAVA_RUN: int
URLACTION_HTML_USERDATA_SAVE: int
URLACTION_HTML_SUBFRAME_NAVIGATE: int
URLACTION_HTML_META_REFRESH: int
URLACTION_HTML_MIXED_CONTENT: int
URLACTION_HTML_INCLUDE_FILE_PATH: int
URLACTION_HTML_MAX: int
URLACTION_SHELL_MIN: int
URLACTION_SHELL_INSTALL_DTITEMS: int
URLACTION_SHELL_MOVE_OR_COPY: int
URLACTION_SHELL_FILE_DOWNLOAD: int
URLACTION_SHELL_VERB: int
URLACTION_SHELL_WEBVIEW_VERB: int
URLACTION_SHELL_SHELLEXECUTE: int
URLACTION_SHELL_EXECUTE_HIGHRISK: int
URLACTION_SHELL_EXECUTE_MODRISK: int
URLACTION_SHELL_EXECUTE_LOWRISK: int
URLACTION_SHELL_POPUPMGR: int
URLACTION_SHELL_RTF_OBJECTS_LOAD: int
URLACTION_SHELL_ENHANCED_DRAGDROP_SECURITY: int
URLACTION_SHELL_EXTENSIONSECURITY: int
URLACTION_SHELL_SECURE_DRAGSOURCE: int
URLACTION_SHELL_CURR_MAX: int
URLACTION_SHELL_MAX: int
URLACTION_NETWORK_MIN: int
URLACTION_CREDENTIALS_USE: int
URLPOLICY_CREDENTIALS_SILENT_LOGON_OK: int
URLPOLICY_CREDENTIALS_MUST_PROMPT_USER: int
URLPOLICY_CREDENTIALS_CONDITIONAL_PROMPT: int
URLPOLICY_CREDENTIALS_ANONYMOUS_ONLY: int
URLACTION_AUTHENTICATE_CLIENT: int
URLPOLICY_AUTHENTICATE_CLEARTEXT_OK: int
URLPOLICY_AUTHENTICATE_CHALLENGE_RESPONSE: int
URLPOLICY_AUTHENTICATE_MUTUAL_ONLY: int
URLACTION_COOKIES: int
URLACTION_COOKIES_SESSION: int
URLACTION_CLIENT_CERT_PROMPT: int
URLACTION_COOKIES_THIRD_PARTY: int
URLACTION_COOKIES_SESSION_THIRD_PARTY: int
URLACTION_COOKIES_ENABLED: int
URLACTION_NETWORK_CURR_MAX: int
URLACTION_NETWORK_MAX: int
URLACTION_JAVA_MIN: int
URLACTION_JAVA_PERMISSIONS: int
URLPOLICY_JAVA_PROHIBIT: int
URLPOLICY_JAVA_HIGH: int
URLPOLICY_JAVA_MEDIUM: int
URLPOLICY_JAVA_LOW: int
URLPOLICY_JAVA_CUSTOM: int
URLACTION_JAVA_CURR_MAX: int
URLACTION_JAVA_MAX: int
URLACTION_INFODELIVERY_MIN: int
URLACTION_INFODELIVERY_NO_ADDING_CHANNELS: int
URLACTION_INFODELIVERY_NO_EDITING_CHANNELS: int
URLACTION_INFODELIVERY_NO_REMOVING_CHANNELS: int
URLACTION_INFODELIVERY_NO_ADDING_SUBSCRIPTIONS: int
URLACTION_INFODELIVERY_NO_EDITING_SUBSCRIPTIONS: int
URLACTION_INFODELIVERY_NO_REMOVING_SUBSCRIPTIONS: int
URLACTION_INFODELIVERY_NO_CHANNEL_LOGGING: int
URLACTION_INFODELIVERY_CURR_MAX: int
URLACTION_INFODELIVERY_MAX: int
URLACTION_CHANNEL_SOFTDIST_MIN: int
URLACTION_CHANNEL_SOFTDIST_PERMISSIONS: int
URLPOLICY_CHANNEL_SOFTDIST_PROHIBIT: int
URLPOLICY_CHANNEL_SOFTDIST_PRECACHE: int
URLPOLICY_CHANNEL_SOFTDIST_AUTOINSTALL: int
URLACTION_CHANNEL_SOFTDIST_MAX: int
URLACTION_BEHAVIOR_MIN: int
URLACTION_BEHAVIOR_RUN: int
URLPOLICY_BEHAVIOR_CHECK_LIST: int
URLACTION_FEATURE_MIN: int
URLACTION_FEATURE_MIME_SNIFFING: int
URLACTION_FEATURE_ZONE_ELEVATION: int
URLACTION_FEATURE_WINDOW_RESTRICTIONS: int
URLACTION_FEATURE_SCRIPT_STATUS_BAR: int
URLACTION_FEATURE_FORCE_ADDR_AND_STATUS: int
URLACTION_FEATURE_BLOCK_INPUT_PROMPTS: int
URLACTION_AUTOMATIC_DOWNLOAD_UI_MIN: int
URLACTION_AUTOMATIC_DOWNLOAD_UI: int
URLACTION_AUTOMATIC_ACTIVEX_UI: int
URLACTION_ALLOW_RESTRICTEDPROTOCOLS: int
URLACTION_ALLOW_APEVALUATION: int
URLACTION_WINDOWS_BROWSER_APPLICATIONS: int
URLACTION_XPS_DOCUMENTS: int
URLACTION_LOOSE_XAML: int
URLACTION_LOWRIGHTS: int
URLACTION_WINFX_SETUP: int
URLPOLICY_ALLOW: int
URLPOLICY_QUERY: int
URLPOLICY_DISALLOW: int
URLPOLICY_NOTIFY_ON_ALLOW: int
URLPOLICY_NOTIFY_ON_DISALLOW: int
URLPOLICY_LOG_ON_ALLOW: int
URLPOLICY_LOG_ON_DISALLOW: int
URLPOLICY_MASK_PERMISSIONS: int
URLPOLICY_DONTCHECKDLGBOX: int
URLZONE_ESC_FLAG: int
SECURITY_IE_STATE_GREEN: int
SECURITY_IE_STATE_RED: int
SOFTDIST_FLAG_USAGE_EMAIL: int
SOFTDIST_FLAG_USAGE_PRECACHE: int
SOFTDIST_FLAG_USAGE_AUTOINSTALL: int
SOFTDIST_FLAG_DELETE_SUBSCRIPTION: int
SOFTDIST_ADSTATE_NONE: int
SOFTDIST_ADSTATE_AVAILABLE: int
SOFTDIST_ADSTATE_DOWNLOADED: int
SOFTDIST_ADSTATE_INSTALLED: int
CONFIRMSAFETYACTION_LOADOBJECT: int



from _typeshed import Incomplete
from typing import Any

class GraphCommands:
    def commit(self): ...
    version: Any
    def query(
        self,
        q,
        params: Incomplete | None = None,
        timeout: Incomplete | None = None,
        read_only: bool = False,
        profile: bool = False,
    ): ...
    def merge(self, pattern): ...
    def delete(self): ...
    nodes: Any
    edges: Any
    def flush(self) -> None: ...
    def explain(self, query, params: Incomplete | None = None): ...
    def bulk(self, **kwargs) -> None: ...
    def profile(self, query): ...
    def slowlog(self): ...
    def config(self, name, value: Incomplete | None = None, set: bool = False): ...
    def list_keys(self): ...



from collections.abc import Callable
from types import TracebackType
from typing import Any, Generic, Protocol, TextIO, TypeVar, overload
from typing_extensions import ParamSpec

import gevent._hub_local
import gevent._waiter
import greenlet
from gevent._hub_primitives import WaitOperationsGreenlet
from gevent._ident import IdentRegistry
from gevent._monitor import PeriodicMonitoringThread
from gevent._types import _Loop, _Watcher
from gevent._util import Lazy, readproperty
from gevent.greenlet import Greenlet
from gevent.resolver import AbstractResolver
from gevent.threadpool import ThreadPool

_T = TypeVar("_T")
_P = ParamSpec("_P")

GreenletExit = greenlet.GreenletExit
getcurrent = greenlet.getcurrent
get_hub = gevent._hub_local.get_hub
Waiter = gevent._waiter.Waiter

class _DefaultReturnProperty(Protocol[_T]):
    @overload
    def __get__(self, obj: None, owner: type[object] | None = None) -> property: ...
    @overload
    def __get__(self, obj: object, owner: type[object] | None = None) -> _T: ...
    def __set__(self, obj: object, value: _T | None) -> None: ...
    def __del__(self, obj: object) -> None: ...

def spawn_raw(function: Callable[..., object], *args: object, **kwargs: object) -> greenlet.greenlet: ...
def sleep(seconds: float = 0, ref: bool = True) -> None: ...
def idle(priority: int = 0) -> None: ...
def kill(greenlet: greenlet.greenlet, exception: type[BaseException] | BaseException = ...) -> None: ...

class signal(Generic[_P]):
    greenlet_class: type[Greenlet[..., Any]] | None
    hub: Hub
    watcher: _Watcher
    handler: Callable[_P, object]
    # we can't use _P.args/_P.kwargs here because pyright will complain
    # mypy doesn't seem to mind though
    args: tuple[Any, ...]
    kwargs: dict[str, Any]
    def __init__(self, signalnum: int, handler: Callable[_P, object], *args: _P.args, **kwargs: _P.kwargs) -> None: ...
    @property
    def ref(self) -> bool: ...
    @ref.setter
    def ref(self, value: bool) -> None: ...
    def cancel(self) -> None: ...
    def handle(self) -> None: ...

def reinit(hub: Hub | None = None) -> None: ...

class Hub(WaitOperationsGreenlet):
    SYSTEM_ERROR: tuple[type[BaseException], ...]
    NOT_ERROR: tuple[type[BaseException], ...]
    threadpool_size: int
    periodic_monitoring_thread: PeriodicMonitoringThread | None
    thread_ident: int
    name: str
    loop: _Loop
    format_context: Callable[[object], str]
    minimal_ident: int
    @overload
    def __init__(self, loop: _Loop, default: None = None) -> None: ...
    @overload
    def __init__(self, loop: None = None, default: bool | None = None) -> None: ...
    @Lazy
    def ident_registry(self) -> IdentRegistry: ...
    @property
    def loop_class(self) -> type[_Loop]: ...
    @property
    def backend(self) -> int | str: ...
    @property
    def main_hub(self) -> bool: ...
    def handle_error(
        self,
        context: object | None,
        type: type[BaseException] | None,
        value: BaseException | str | None,
        tb: TracebackType | None,
    ) -> None: ...
    def handle_system_error(
        self, type: type[BaseException], value: BaseException | None, tb: TracebackType | None = None
    ) -> None: ...
    @readproperty
    def exception_stream(self) -> TextIO | None: ...
    def print_exception(
        self, context: object | None, t: type[BaseException] | None, v: BaseException | str | None, tb: TracebackType | None
    ) -> None: ...
    def run(self) -> None: ...
    def start_periodic_monitoring_thread(self) -> PeriodicMonitoringThread: ...
    def join(self, timeout: float | None = None) -> bool: ...
    def destroy(self, destroy_loop: bool | None = None) -> None: ...
    @property
    def resolver_class(self) -> type[AbstractResolver]: ...
    resolver: _DefaultReturnProperty[AbstractResolver]
    @property
    def threadpool_class(self) -> type[ThreadPool]: ...
    threadpool: _DefaultReturnProperty[ThreadPool]

class linkproxy:
    callback: Callable[[object], object]
    obj: object
    def __init__(self, callback: Callable[[_T], object], obj: _T) -> None: ...
    def __call__(self, *args: object) -> None: ...



from _typeshed import Incomplete
from typing import ClassVar

from .core import UnitedStates

class SouthCarolina(UnitedStates):
    FIXED_HOLIDAYS: Incomplete
    include_thanksgiving_friday: ClassVar[bool]
    include_christmas_eve: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    include_columbus_day: ClassVar[bool]



from _typeshed import Incomplete
from collections.abc import Callable, Iterable

from networkx.classes.graph import Graph, _Data, _Node
from networkx.utils.backends import _dispatch

__all__ = [
    "to_networkx_graph",
    "from_dict_of_dicts",
    "to_dict_of_dicts",
    "from_dict_of_lists",
    "to_dict_of_lists",
    "from_edgelist",
    "to_edgelist",
]

def to_networkx_graph(
    data: _Data[_Node], create_using: Graph[_Node] | Callable[[], Graph[_Node]] | None = None, multigraph_input: bool = False
) -> Graph[_Node]: ...
@_dispatch
def to_dict_of_lists(G: Graph[_Node], nodelist: None | Iterable[_Node] = None) -> dict[_Node, list[_Node]]: ...
@_dispatch
def from_dict_of_lists(d: dict[_Node, Iterable[_Node]], create_using: Incomplete | None = None): ...
def to_dict_of_dicts(G, nodelist=None, edge_data=None) -> dict[Incomplete, Incomplete]: ...
@_dispatch
def from_dict_of_dicts(d, create_using=None, multigraph_input=False): ...
@_dispatch
def to_edgelist(G, nodelist=None): ...
@_dispatch
def from_edgelist(edgelist, create_using=None): ...



from _typeshed import Incomplete
from ssl import SSLObject, SSLSocket
from typing import Literal

from cryptography.x509.base import Certificate
from OpenSSL.SSL import Connection

def ocsp_staple_verifier(con: Connection, ocsp_bytes: bytes, expected: bytes | None = None) -> Literal[True]: ...

class OCSPVerifier:
    SOCK: SSLObject | SSLSocket
    HOST: str
    PORT: int
    CA_CERTS: str | None
    def __init__(self, sock: SSLObject | SSLSocket, host: str, port: int, ca_certs: str | None = None) -> None: ...
    # cryptography.x509.general_name.GeneralName.value is typed as Any
    def components_from_socket(self) -> tuple[Certificate, Incomplete | None, Incomplete]: ...
    def components_from_direct_connection(self) -> tuple[Certificate, Incomplete | None, Incomplete]: ...
    def build_certificate_url(self, server: str, cert: Certificate, issuer_cert: Certificate) -> str: ...
    def check_certificate(self, server: str, cert: Certificate, issuer_url: str | bytes) -> Literal[True]: ...
    def is_valid(self) -> Literal[True]: ...



from _typeshed import Incomplete

from stripe.error import StripeError as StripeError

class OAuthError(StripeError):
    def __init__(
        self,
        code,
        description,
        http_body: Incomplete | None = None,
        http_status: Incomplete | None = None,
        json_body: Incomplete | None = None,
        headers: Incomplete | None = None,
    ) -> None: ...
    def construct_error_object(self): ...

class InvalidClientError(OAuthError): ...
class InvalidGrantError(OAuthError): ...
class InvalidRequestError(OAuthError): ...
class InvalidScopeError(OAuthError): ...
class UnsupportedGrantTypeError(OAuthError): ...
class UnsupportedResponseTypeError(OAuthError): ...



from typing import Any

from .base import NonRecursiveTreeWalker

def ensure_str(s): ...

class Root:
    elementtree: Any
    children: Any
    text: Any
    tail: Any
    def __init__(self, et) -> None: ...
    def __getitem__(self, key): ...
    def getnext(self) -> None: ...
    def __len__(self) -> int: ...

class Doctype:
    root_node: Any
    name: Any
    public_id: Any
    system_id: Any
    text: Any
    tail: Any
    def __init__(self, root_node, name, public_id, system_id) -> None: ...
    def getnext(self): ...

class FragmentRoot(Root):
    children: Any
    text: Any
    def __init__(self, children) -> None: ...
    def getnext(self) -> None: ...

class FragmentWrapper:
    root_node: Any
    obj: Any
    text: Any
    tail: Any
    def __init__(self, fragment_root, obj) -> None: ...
    def __getattr__(self, name: str): ...
    def getnext(self): ...
    def __getitem__(self, key): ...
    def __bool__(self) -> bool: ...
    def getparent(self) -> None: ...
    def __unicode__(self) -> str: ...
    def __len__(self) -> int: ...

class TreeWalker(NonRecursiveTreeWalker):
    fragmentChildren: Any
    filter: Any
    def __init__(self, tree) -> None: ...
    def getNodeDetails(self, node): ...
    def getFirstChild(self, node): ...
    def getNextSibling(self, node): ...
    def getParentNode(self, node): ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class UnitedKingdom(WesternCalendar):
    include_good_friday: ClassVar[bool]
    include_easter_sunday: ClassVar[bool]
    include_easter_monday: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    shift_new_years_day: ClassVar[bool]
    non_computable_holiday_dict: Incomplete
    def get_early_may_bank_holiday(self, year): ...
    def get_spring_bank_holiday(self, year): ...
    def get_late_summer_bank_holiday(self, year): ...
    def non_computable_holiday(self, year): ...
    def get_variable_days(self, year): ...

class UnitedKingdomNorthernIreland(UnitedKingdom):
    def get_variable_days(self, year): ...



from _typeshed import Incomplete
from typing import Any

from .base import BaseEndpoint as BaseEndpoint

log: Any

class RequestTokenEndpoint(BaseEndpoint):
    def create_request_token(self, request, credentials): ...
    def create_request_token_response(
        self,
        uri,
        http_method: str = "GET",
        body: Incomplete | None = None,
        headers: Incomplete | None = None,
        credentials: Incomplete | None = None,
    ): ...
    def validate_request_token_request(self, request): ...



import re
import subprocess
from _typeshed import Incomplete
from builtins import range as _range
from collections import OrderedDict
from collections.abc import Callable, Generator, Iterable, Iterator
from datetime import datetime
from logging import Logger
from types import TracebackType
from typing import Any, SupportsIndex, overload
from typing_extensions import Self, TypeAlias

from cronlog import CronLog

_User: TypeAlias = str | bool | None

__pkgname__: str
ITEMREX: re.Pattern[str]
SPECREX: re.Pattern[str]
DEVNULL: str
WEEK_ENUM: list[str]
MONTH_ENUM: list[str | None]
SPECIALS: dict[str, str]
SPECIAL_IGNORE: list[str]
S_INFO: list[dict[str, Any]]
WINOS: bool
POSIX: bool
SYSTEMV: bool
ZERO_PAD: bool
LOG: Logger
CRON_COMMAND: str
SHELL: str
current_user: Callable[[], str | None]

class Process:
    env: subprocess._ENV | None
    args: tuple[str, ...]
    has_run: bool
    stdout: str | None
    stderr: str | None
    returncode: int | None
    # `posix` and `env` are known special kwargs:
    def __init__(self, cmd: str, *args: str, posix: bool = ..., env: subprocess._ENV | None = None, **flags: object) -> None: ...
    def run(self) -> Self: ...
    def __int__(self) -> int: ...  # technically, it can return `None` before `run` is called
    def __eq__(self, other: object) -> bool: ...

class CronTab:
    lines: list[str | CronItem] | None
    crons: list[CronItem] | None
    filen: str | None
    cron_command: str
    env: OrderedVariableList | None
    root: bool
    intab: str | None
    tabfile: str | None
    def __init__(
        self, user: _User = ..., tab: str | None = ..., tabfile: str | None = ..., log: CronLog | str | None = ...
    ) -> None: ...
    def __enter__(self) -> Self: ...
    def __exit__(
        self, exc_type: type[BaseException] | None, exc_val: BaseException | None, exc_tb: TracebackType | None
    ) -> None: ...
    @property
    def log(self) -> CronLog: ...
    @property
    def user(self) -> _User: ...
    @property
    def user_opt(self) -> dict[str, str]: ...
    def read(self, filename: str | None = ...) -> None: ...
    def append(
        self,
        item: CronItem,
        line: str = ...,
        read: bool = ...,
        before: str | re.Pattern[str] | list[CronItem] | tuple[CronItem, ...] | Generator[CronItem, Any, Any] | None = ...,
    ) -> None: ...
    def write(self, filename: str | None = ..., user: _User = ..., errors: bool = ...) -> None: ...
    def write_to_user(self, user: bool | str = ...) -> None: ...
    # Usually `kwargs` are just `now: datetime | None`, but technically this can
    # work for `CronItem` subclasses, which might define other kwargs.
    def run_pending(self, **kwargs: Any) -> Iterator[str]: ...
    def run_scheduler(self, timeout: int = -1, cadence: int = 60, warp: bool = False) -> Iterator[str]: ...
    def render(self, errors: bool = ..., specials: bool | None = ...) -> str: ...
    def new(
        self,
        command: str = ...,
        comment: str = ...,
        user: str | None = ...,
        pre_comment: bool = ...,
        before: str | re.Pattern[str] | list[CronItem] | tuple[CronItem, ...] | Generator[CronItem, Any, Any] | None = ...,
    ) -> CronItem: ...
    def find_command(self, command: str | re.Pattern[str]) -> Iterator[CronItem]: ...
    def find_comment(self, comment: str | re.Pattern[str]) -> Iterator[CronItem]: ...
    def find_time(self, *args: Any) -> Iterator[CronItem]: ...
    @property
    def commands(self) -> Iterator[str]: ...
    @property
    def comments(self) -> Iterator[str]: ...
    # You cannot actually pass `*args`, it will raise an exception,
    # also known kwargs are added:
    def remove_all(
        self, *, command: str | re.Pattern[str] = ..., comment: str | re.Pattern[str] = ..., time: Any = ..., **kwargs: object
    ) -> int: ...
    def remove(self, *items: CronItem | Iterable[CronItem]) -> int: ...
    def __iter__(self) -> Iterator[CronItem]: ...
    def __getitem__(self, i: SupportsIndex) -> CronItem: ...
    def __len__(self) -> int: ...

class CronItem:
    cron: CronTab | None
    user: _User
    valid: bool
    enabled: bool
    special: bool
    comment: str
    command: str | None
    last_run: datetime | None
    env: OrderedVariableList
    pre_comment: bool
    marker: str | None
    stdin: str | None
    slices: CronSlices
    def __init__(self, command: str = ..., comment: str = ..., user: _User = ..., pre_comment: bool = ...) -> None: ...
    def __hash__(self) -> int: ...
    def __eq__(self, other: object) -> bool: ...
    @classmethod
    def from_line(cls, line: str, user: str | None = ..., cron: Incomplete | None = ...) -> Self: ...
    def delete(self) -> None: ...
    def set_command(self, cmd: str, parse_stdin: bool = ...) -> None: ...
    def set_comment(self, cmt: str, pre_comment: bool = ...) -> None: ...
    def parse(self, line: str) -> None: ...
    def enable(self, enabled: bool = ...) -> bool: ...
    def is_enabled(self) -> bool: ...
    def is_valid(self) -> bool: ...
    def render(self, specials: bool = ...) -> str: ...
    def every_reboot(self) -> None: ...
    def every(self, unit: int = ...) -> Every: ...
    def setall(self, *args: Any) -> None: ...
    def clear(self) -> None: ...
    def frequency(self, year: int | None = ...) -> int: ...
    def frequency_per_year(self, year: int | None = ...) -> int: ...
    def frequency_per_day(self) -> int: ...
    def frequency_per_hour(self) -> int: ...
    def frequency_at_year(self, year: int | None = None) -> int: ...
    @overload
    def frequency_at_month(self, year: int, month: int) -> int: ...
    @overload
    def frequency_at_month(self, year: None = None, month: None = None) -> int: ...
    @overload
    def frequency_at_day(self, year: int, month: int, day: int) -> int: ...
    @overload
    def frequency_at_day(self, year: None = None, month: None = None, day: None = None) -> int: ...
    @overload
    def frequency_at_hour(self, year: int, month: int, day: int, hour: int) -> int: ...
    @overload
    def frequency_at_hour(self, year: None = None, month: None = None, day: None = None, hour: None = None) -> int: ...
    def run_pending(self, now: datetime | None = ...) -> int | str: ...
    def run(self) -> str: ...
    # TODO: use types from `croniter` module here:
    def schedule(self, date_from: datetime | None = ...) -> Incomplete: ...
    # TODO: use types from `cron_descriptor` here:
    def description(self, **kw: Incomplete) -> Incomplete: ...
    @property
    def log(self) -> CronLog: ...
    @property
    def minute(self) -> int | str: ...
    @property
    def minutes(self) -> int | str: ...
    @property
    def hour(self) -> int | str: ...
    @property
    def hours(self) -> int | str: ...
    @property
    def day(self) -> int | str: ...
    @property
    def dom(self) -> int | str: ...
    @property
    def month(self) -> int | str: ...
    @property
    def months(self) -> int | str: ...
    @property
    def dow(self) -> int | str: ...
    def __len__(self) -> int: ...
    def __getitem__(self, key: int | str) -> int | str: ...
    def __lt__(self, value: object) -> bool: ...
    def __gt__(self, value: object) -> bool: ...

class Every:
    slices: CronSlices
    unit: int
    # TODO: add generated attributes
    def __init__(self, item: CronSlices, units: int) -> None: ...
    def set_attr(self, target: int) -> Callable[[], None]: ...
    def year(self) -> None: ...

class CronSlices(list[CronSlice]):
    special: bool | None
    def __init__(self, *args: Any) -> None: ...
    def is_self_valid(self, *args: Any) -> bool: ...
    @classmethod
    def is_valid(cls, *args: Any) -> bool: ...
    def setall(self, *slices: str) -> None: ...
    def clean_render(self) -> str: ...
    def render(self, specials: bool = ...) -> str: ...
    def clear(self) -> None: ...
    def frequency(self, year: int | None = ...) -> int: ...
    def frequency_per_year(self, year: int | None = ...) -> int: ...
    def frequency_per_day(self) -> int: ...
    def frequency_per_hour(self) -> int: ...
    def frequency_at_year(self, year: int | None = None) -> int: ...
    @overload
    def frequency_at_month(self, year: int, month: int) -> int: ...
    @overload
    def frequency_at_month(self, year: None = None, month: None = None) -> int: ...
    @overload
    def frequency_at_day(self, year: int, month: int, day: int) -> int: ...
    @overload
    def frequency_at_day(self, year: None = None, month: None = None, day: None = None) -> int: ...
    @overload
    def frequency_at_hour(self, year: int, month: int, day: int, hour: int) -> int: ...
    @overload
    def frequency_at_hour(self, year: None = None, month: None = None, day: None = None, hour: None = None) -> int: ...
    def __eq__(self, arg: object) -> bool: ...

class SundayError(KeyError): ...

class Also:
    obj: CronSlice
    def __init__(self, obj: CronSlice) -> None: ...
    # These method actually use `*args`, but pass them to `CronSlice` methods,
    # this is why they are typed as `Any`.
    def every(self, *a: Any) -> _Part: ...
    def on(self, *a: Any) -> list[_Part]: ...
    def during(self, *a: Any) -> _Part: ...

_Part: TypeAlias = int | CronValue | CronRange

class CronSlice:
    min: int | None
    max: int | None
    name: str | None
    enum: list[str | None] | None
    parts: list[_Part]
    def __init__(self, info: int | dict[str, Any], value: str | None = ...) -> None: ...
    def __hash__(self) -> int: ...
    def parse(self, value: str | None) -> None: ...
    def render(self, resolve: bool = False) -> str: ...
    def __eq__(self, arg: object) -> bool: ...
    def every(self, n_value: int, also: bool = ...) -> _Part: ...
    # The only known kwarg, others are unused,
    # `*args`` are passed to `parse_value`, so they are `Any`
    def on(self, *n_value: Any, also: bool = ...) -> list[_Part]: ...
    def during(self, vfrom: int | str, vto: int | str, also: bool = ...) -> _Part: ...
    @property
    def also(self) -> Also: ...
    def clear(self) -> None: ...
    def get_range(self, *vrange: int | str | CronValue) -> list[int | CronRange]: ...
    def __iter__(self) -> Iterator[int]: ...
    def __len__(self) -> int: ...
    def parse_value(self, val: str, sunday: int | None = ...) -> int | CronValue: ...

def get_cronvalue(value: int, enums: list[str]) -> int | CronValue: ...

class CronValue:
    text: str
    value: int
    def __init__(self, value: str, enums: list[str]) -> None: ...
    def __lt__(self, value: object) -> bool: ...
    def __int__(self) -> int: ...

class CronRange:
    dangling: int | None
    slice: str
    cron: CronTab | None
    seq: int
    def __init__(self, vslice: str, *vrange: int | str | CronValue) -> None: ...
    # Are not set in `__init__`:
    vfrom: int | CronValue
    vto: int | CronValue
    def parse(self, value: str) -> None: ...
    def all(self) -> None: ...
    def render(self, resolve: bool = ...) -> str: ...
    def range(self) -> _range: ...
    def every(self, value: int | str) -> None: ...
    def __lt__(self, value: object) -> bool: ...
    def __gt__(self, value: object) -> bool: ...
    def __int__(self) -> int: ...

# TODO: make generic
class OrderedVariableList(OrderedDict[Incomplete, Incomplete]):
    job: Incomplete
    def __init__(self, *args: Any, **kw: Any) -> None: ...
    @property
    def previous(self) -> Incomplete: ...
    def all(self) -> Self: ...
    def __getitem__(self, key: Incomplete) -> Incomplete: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def gn_graph(n, kernel: Incomplete | None = None, create_using: Incomplete | None = None, seed: Incomplete | None = None): ...
@_dispatch
def gnr_graph(n, p, create_using: Incomplete | None = None, seed: Incomplete | None = None): ...
@_dispatch
def gnc_graph(n, create_using: Incomplete | None = None, seed: Incomplete | None = None): ...
@_dispatch
def scale_free_graph(
    n,
    alpha: float = 0.41,
    beta: float = 0.54,
    gamma: float = 0.05,
    delta_in: float = 0.2,
    delta_out: float = 0,
    create_using: Incomplete | None = None,
    seed: Incomplete | None = None,
    initial_graph: Incomplete | None = None,
): ...
@_dispatch
def random_k_out_graph(n, k, alpha, self_loops: bool = True, seed: Incomplete | None = None): ...



from win32com.server.exception import COMException

debugging: int

def FormatForAX(text): ...
def ExpandTabs(text): ...
def AddCR(text): ...

class IActiveScriptError:
    def GetSourceLineText(self): ...
    def GetSourcePosition(self): ...
    def GetExceptionInfo(self): ...

class AXScriptException(COMException):
    sourceContext: int
    startLineNo: int
    linetext: str
    def __init__(self, site, codeBlock, exc_type, exc_value, exc_traceback) -> None: ...
    def ExtractTracebackInfo(self, tb, site): ...

def ProcessAXScriptException(scriptingSite, debugManager, exceptionInstance): ...



from __future__ import annotations

from json import loads
from pathlib import Path
from shutil import copyfile, copytree
from typing import TYPE_CHECKING, TypedDict, cast

# https://github.com/samwillis/nodejs-pypi/pull/23
if TYPE_CHECKING:
    # https://github.com/astral-sh/ruff/issues/9528
    from subprocess import run  # noqa: S404
else:
    from nodejs.npm import run


class PackageJson(TypedDict):
    bin: dict[str, str]


_ = run(["ci"], check=True)
_ = run(["run", "build:cli:dev"], check=True)

npm_package_dir = Path("packages/pyright")
pypi_package_dir = Path("basedpyright")

copytree(npm_package_dir / "dist", pypi_package_dir / "dist", dirs_exist_ok=True)
for script_path in cast(PackageJson, loads((npm_package_dir / "package.json").read_text()))[
    "bin"
].values():
    _ = copyfile(npm_package_dir / script_path, pypi_package_dir / script_path)



from stripe.api_resources.terminal.connection_token import ConnectionToken as ConnectionToken
from stripe.api_resources.terminal.location import Location as Location
from stripe.api_resources.terminal.reader import Reader as Reader



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

__all__ = ["could_be_isomorphic", "fast_could_be_isomorphic", "faster_could_be_isomorphic", "is_isomorphic"]

@_dispatch
def could_be_isomorphic(G1, G2): ...

graph_could_be_isomorphic = could_be_isomorphic

@_dispatch
def fast_could_be_isomorphic(G1, G2): ...

fast_graph_could_be_isomorphic = fast_could_be_isomorphic

@_dispatch
def faster_could_be_isomorphic(G1, G2): ...

faster_graph_could_be_isomorphic = faster_could_be_isomorphic

@_dispatch
def is_isomorphic(G1, G2, node_match: Incomplete | None = None, edge_match: Incomplete | None = None): ...



from typing import Any

from markdown.extensions import Extension

extensions: Any

class ExtraExtension(Extension):
    def __init__(self, **kwargs) -> None: ...

def makeExtension(**kwargs) -> ExtraExtension: ...



from _typeshed import Incomplete

class NotificationRuleBase:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        latest_completed: Incomplete | None = None,
        last_run_status: Incomplete | None = None,
        last_run_error: Incomplete | None = None,
        id: Incomplete | None = None,
        endpoint_id: Incomplete | None = None,
        org_id: Incomplete | None = None,
        task_id: Incomplete | None = None,
        owner_id: Incomplete | None = None,
        created_at: Incomplete | None = None,
        updated_at: Incomplete | None = None,
        status: Incomplete | None = None,
        name: Incomplete | None = None,
        sleep_until: Incomplete | None = None,
        every: Incomplete | None = None,
        offset: Incomplete | None = None,
        runbook_link: Incomplete | None = None,
        limit_every: Incomplete | None = None,
        limit: Incomplete | None = None,
        tag_rules: Incomplete | None = None,
        description: Incomplete | None = None,
        status_rules: Incomplete | None = None,
        labels: Incomplete | None = None,
        links: Incomplete | None = None,
    ) -> None: ...
    @property
    def latest_completed(self): ...
    @latest_completed.setter
    def latest_completed(self, latest_completed) -> None: ...
    @property
    def last_run_status(self): ...
    @last_run_status.setter
    def last_run_status(self, last_run_status) -> None: ...
    @property
    def last_run_error(self): ...
    @last_run_error.setter
    def last_run_error(self, last_run_error) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def endpoint_id(self): ...
    @endpoint_id.setter
    def endpoint_id(self, endpoint_id) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def task_id(self): ...
    @task_id.setter
    def task_id(self, task_id) -> None: ...
    @property
    def owner_id(self): ...
    @owner_id.setter
    def owner_id(self, owner_id) -> None: ...
    @property
    def created_at(self): ...
    @created_at.setter
    def created_at(self, created_at) -> None: ...
    @property
    def updated_at(self): ...
    @updated_at.setter
    def updated_at(self, updated_at) -> None: ...
    @property
    def status(self): ...
    @status.setter
    def status(self, status) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def sleep_until(self): ...
    @sleep_until.setter
    def sleep_until(self, sleep_until) -> None: ...
    @property
    def every(self): ...
    @every.setter
    def every(self, every) -> None: ...
    @property
    def offset(self): ...
    @offset.setter
    def offset(self, offset) -> None: ...
    @property
    def runbook_link(self): ...
    @runbook_link.setter
    def runbook_link(self, runbook_link) -> None: ...
    @property
    def limit_every(self): ...
    @limit_every.setter
    def limit_every(self, limit_every) -> None: ...
    @property
    def limit(self): ...
    @limit.setter
    def limit(self, limit) -> None: ...
    @property
    def tag_rules(self): ...
    @tag_rules.setter
    def tag_rules(self, tag_rules) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def status_rules(self): ...
    @status_rules.setter
    def status_rules(self, status_rules) -> None: ...
    @property
    def labels(self): ...
    @labels.setter
    def labels(self, labels) -> None: ...
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from collections.abc import Iterable
from typing import ClassVar, Final, Literal
from typing_extensions import deprecated

from ._imaging import _PixelAccessor
from .ImageFile import ImageFile

COMPRESSION: dict[int, str]
PAD: Final[bytes]

@deprecated("Deprecated since 10.2.0")
def i(c: bytes) -> int: ...
@deprecated("Deprecated since 10.2.0")
def dump(c: Iterable[int | bytes]) -> None: ...

class IptcImageFile(ImageFile):
    format: ClassVar[Literal["IPTC"]]
    format_description: ClassVar[str]
    def getint(self, key: tuple[int, int]) -> int: ...
    def field(self) -> tuple[tuple[int, int] | None, int]: ...
    def load(self) -> _PixelAccessor: ...

def getiptcinfo(im): ...



from _typeshed import Incomplete, Unused
from collections.abc import Sequence
from typing import SupportsInt, overload
from typing_extensions import TypeAlias, deprecated

import _win32typing
from win32.lib.pywintypes import TimeType, com_error as com_error

error: TypeAlias = com_error  # noqa: Y042

class internal_error(Exception): ...

def CoCreateFreeThreadedMarshaler(unk: _win32typing.PyIUnknown, /) -> _win32typing.PyIUnknown: ...
def CoCreateInstanceEx(
    clsid: _win32typing.PyIID,
    unkOuter: _win32typing.PyIUnknown,
    context,
    serverInfo: tuple[Incomplete, Incomplete, Incomplete, Incomplete],
    iids: list[_win32typing.PyIID],
    /,
) -> _win32typing.PyIUnknown: ...
def CoCreateInstance(
    clsid: _win32typing.PyIID, unkOuter: _win32typing.PyIUnknown | None, context: int, iid: _win32typing.PyIID, /
) -> _win32typing.PyIUnknown: ...
def CoFreeUnusedLibraries() -> None: ...
def CoInitialize() -> None: ...
def CoInitializeEx(flags, /) -> None: ...
def CoInitializeSecurity(
    sd: _win32typing.PySECURITY_DESCRIPTOR, authSvc, reserved1, authnLevel, impLevel, authInfo, capabilities, reserved2, /
) -> None: ...
def CoGetInterfaceAndReleaseStream(stream: _win32typing.PyIStream, iid: _win32typing.PyIID, /) -> _win32typing.PyIUnknown: ...
def CoMarshalInterThreadInterfaceInStream(iid: _win32typing.PyIID, unk: _win32typing.PyIUnknown, /) -> _win32typing.PyIStream: ...
def CoMarshalInterface(
    Stm: _win32typing.PyIStream, riid: _win32typing.PyIID, Unk: _win32typing.PyIUnknown, DestContext, flags, /
) -> None: ...
def CoUnmarshalInterface(Stm: _win32typing.PyIStream, riid: _win32typing.PyIID, /): ...
def CoReleaseMarshalData(Stm: _win32typing.PyIStream, /) -> None: ...
def CoGetObject(name: str, iid: _win32typing.PyIID, bindOpts: Incomplete | None = ..., /) -> _win32typing.PyIUnknown: ...
def CoUninitialize() -> None: ...
def CoRegisterClassObject(iid: _win32typing.PyIID, factory: _win32typing.PyIUnknown, context, flags, /): ...
def CoResumeClassObjects() -> None: ...
def CoRevokeClassObject(reg, /) -> None: ...
def CoTreatAsClass(clsidold: _win32typing.PyIID, clsidnew: _win32typing.PyIID, /) -> None: ...
def CoWaitForMultipleHandles(Flags, Timeout, Handles: list[int], /): ...
def Connect(cls, /) -> _win32typing.PyIDispatch: ...
def connect(*args): ...  # incomplete
def CreateGuid() -> _win32typing.PyIID: ...
def CreateBindCtx() -> _win32typing.PyIBindCtx: ...
def CreateFileMoniker(filename: str, /) -> _win32typing.PyIMoniker: ...
def CreateItemMoniker(delim: str, item: str, /) -> _win32typing.PyIMoniker: ...
def CreatePointerMoniker(IUnknown: _win32typing.PyIUnknown, /) -> _win32typing.PyIMoniker: ...
def CreateURLMonikerEx(*args): ...  # incomplete
def CreateTypeLib(): ...
def CreateTypeLib2(): ...
def CreateStreamOnHGlobal(hGlobal: int | None = ..., DeleteOnRelease: bool = ..., /) -> _win32typing.PyIStream: ...
def CreateILockBytesOnHGlobal(hGlobal: int | None = ..., DeleteOnRelease: bool = ..., /) -> _win32typing.PyILockBytes: ...
def EnableQuitMessage(threadId, /) -> None: ...
def FUNCDESC() -> _win32typing.FUNCDESC: ...
def GetActiveObject(cls, /) -> _win32typing.PyIUnknown: ...
def GetClassFile(fileName, /) -> _win32typing.PyIID: ...
def GetFacilityString(scode, /) -> str: ...
def GetRecordFromGuids(
    iid: _win32typing.PyIID, verMajor, verMinor, lcid, infoIID: _win32typing.PyIID, data: Incomplete | None = ..., /
): ...
def GetRecordFromTypeInfo(TypeInfo: _win32typing.PyITypeInfo, /): ...
def GetRunningObjectTable(reserved: int = ..., /) -> _win32typing.PyIRunningObjectTable: ...
def GetScodeString(scode, /) -> str: ...
def GetScodeRangeString(scode, /) -> str: ...
def GetSeverityString(scode, /) -> str: ...
def IsGatewayRegistered(iid: _win32typing.PyIID | None, /) -> int: ...
def LoadRegTypeLib(iid: _win32typing.PyIID, versionMajor, versionMinor, lcid, /) -> _win32typing.PyITypeLib: ...
def LoadTypeLib(libFileName: str, /) -> _win32typing.PyITypeLib: ...
def MakePyFactory(iid: _win32typing.PyIID, /) -> _win32typing.PyIClassFactory: ...
@deprecated("Use pywintypes.IID() instead.")
def MakeIID(iidString: str, is_bytes: bool = ..., /) -> _win32typing.PyIID: ...
@deprecated("Use pywintypes.Time() instead.")
def MakeTime(timeRepr: SupportsInt | Sequence[SupportsInt] | TimeType, /) -> TimeType: ...
def MkParseDisplayName(
    displayName: str, bindCtx: _win32typing.PyIBindCtx | None = ..., /
) -> tuple[_win32typing.PyIMoniker, Incomplete, _win32typing.PyIBindCtx]: ...
def new(iid: _win32typing.PyIID | str, /): ...
def New(cls, /) -> _win32typing.PyIDispatch: ...
def ObjectFromAddress(address, iid: _win32typing.PyIID, /) -> _win32typing.PyIUnknown: ...
def ObjectFromLresult(lresult, iid: _win32typing.PyIID, wparm, /) -> _win32typing.PyIUnknown: ...
def OleInitialize() -> None: ...
def OleGetClipboard() -> _win32typing.PyIDataObject: ...
def OleFlushClipboard() -> None: ...
def OleIsCurrentClipboard(dataObj: _win32typing.PyIDataObject, /): ...
def OleSetClipboard(dataObj: _win32typing.PyIDataObject, /) -> None: ...
def OleLoadFromStream(stream: _win32typing.PyIStream, iid: _win32typing.PyIID, /) -> None: ...
def OleSaveToStream(persist: _win32typing.PyIPersistStream, stream: _win32typing.PyIStream, /) -> None: ...
def OleLoad(storage: _win32typing.PyIStorage, iid: _win32typing.PyIID, site: _win32typing.PyIOleClientSite, /) -> None: ...
def ProgIDFromCLSID(clsid, /) -> str: ...
def PumpWaitingMessages(firstMessage: int = ..., lastMessage: int = ..., /) -> int: ...
def PumpMessages() -> None: ...
def QueryPathOfRegTypeLib(iid: _win32typing.PyIID, versionMajor, versionMinor, lcid, /) -> str: ...
def ReadClassStg(storage: _win32typing.PyIStorage, /) -> _win32typing.PyIID: ...
def ReadClassStm(Stm: _win32typing.PyIStream, /) -> _win32typing.PyIID: ...
def RegisterTypeLib(typelib: _win32typing.PyITypeLib, fullPath: str, lcid, helpDir: str | None = ..., /) -> None: ...
def UnRegisterTypeLib(iid: _win32typing.PyIID, versionMajor, versionMinor, lcid, syskind, /) -> str: ...
def RegisterActiveObject(obUnknown: _win32typing.PyIUnknown, clsid: _win32typing.PyIID, flags, /): ...
def RevokeActiveObject(handle, /) -> None: ...
def RegisterDragDrop(hwnd: int, dropTarget: _win32typing.PyIDropTarget, /) -> None: ...
def RevokeDragDrop(hwnd: int, /) -> None: ...
def DoDragDrop() -> None: ...
def StgCreateDocfile(name: str | None, mode: int, reserved: int = ..., /) -> _win32typing.PyIStorage: ...
def StgCreateDocfileOnILockBytes(lockBytes: _win32typing.PyILockBytes, mode, reserved=..., /) -> _win32typing.PyIStorage: ...
def StgOpenStorageOnILockBytes(
    lockBytes: _win32typing.PyILockBytes,
    stgPriority: _win32typing.PyIStorage,
    mode,
    snbExclude: Incomplete | None = ...,
    reserved: int = ...,
    /,
) -> _win32typing.PyIStorage: ...
def StgIsStorageFile(name: str, /): ...
def STGMEDIUM() -> _win32typing.PySTGMEDIUM: ...
@overload
def StgOpenStorage(
    name: str | None, other: _win32typing.PyIStorage, mode: int, snbExclude: Unused = ..., reserved: int = ..., /
) -> _win32typing.PyIStorage: ...
@overload
def StgOpenStorage(
    name: str, other: _win32typing.PyIStorage | None, mode: int, snbExclude: Unused = ..., reserved: int = ..., /
) -> _win32typing.PyIStorage: ...
def StgOpenStorageEx(
    Name: str, Mode: int, stgfmt: int, Attrs: int, riid: _win32typing.PyIID, StgOptions: Incomplete | None = ...
) -> _win32typing.PyIStorage: ...
def StgCreateStorageEx(
    Name: str,
    Mode: int,
    stgfmt: int,
    Attrs: int,
    riid: _win32typing.PyIID,
    StgOptions: Incomplete | None = ...,
    SecurityDescriptor: _win32typing.PySECURITY_DESCRIPTOR | None = ...,
) -> _win32typing.PyIStorage: ...
def TYPEATTR() -> _win32typing.TYPEATTR: ...
def VARDESC() -> _win32typing.VARDESC: ...
def WrapObject(ob, gatewayIID: _win32typing.PyIID, interfaceIID: _win32typing.PyIID, /) -> _win32typing.PyIUnknown: ...
def WriteClassStg(storage: _win32typing.PyIStorage, iid: _win32typing.PyIID, /) -> None: ...
def WriteClassStm(Stm: _win32typing.PyIStream, clsid: _win32typing.PyIID, /) -> None: ...
def UnwrapObject(ob: _win32typing.PyIUnknown, /) -> _win32typing.PyIDispatch: ...
def FmtIdToPropStgName(fmtid: _win32typing.PyIID, /): ...
def PropStgNameToFmtId(Name: str, /) -> _win32typing.PyIID: ...
def CoGetCallContext(riid: _win32typing.PyIID, /) -> _win32typing.PyIServerSecurity: ...
def CoGetObjectContext(riid: _win32typing.PyIID, /) -> _win32typing.PyIContext: ...
def CoGetCancelObject(riid: _win32typing.PyIID, ThreadID: int = ..., /) -> _win32typing.PyICancelMethodCalls: ...
def CoSetCancelObject(Unk: _win32typing.PyIUnknown, /) -> None: ...
def CoEnableCallCancellation() -> None: ...
def CoDisableCallCancellation() -> None: ...

ACTIVEOBJECT_STRONG: int
ACTIVEOBJECT_WEAK: int
ArgNotFound: _win32typing.ArgNotFound
CLSCTX_ALL: int
CLSCTX_INPROC: int
CLSCTX_INPROC_HANDLER: int
CLSCTX_INPROC_SERVER: int
CLSCTX_LOCAL_SERVER: int
CLSCTX_REMOTE_SERVER: int
CLSCTX_SERVER: int
CLSID_DCOMAccessControl: _win32typing.PyIID
CLSID_StdComponentCategoriesMgr: _win32typing.PyIID
CLSID_StdGlobalInterfaceTable: _win32typing.PyIID
COINIT_APARTMENTTHREADED: int
COINIT_DISABLE_OLE1DDE: int
COINIT_MULTITHREADED: int
COINIT_SPEED_OVER_MEMORY: int
COWAIT_ALERTABLE: int
COWAIT_WAITALL: int
DATADIR_GET: int
DATADIR_SET: int
DESCKIND_FUNCDESC: int
DESCKIND_VARDESC: int
DISPATCH_METHOD: int
DISPATCH_PROPERTYGET: int
DISPATCH_PROPERTYPUT: int
DISPATCH_PROPERTYPUTREF: int
DISPID_COLLECT: int
DISPID_CONSTRUCTOR: int
DISPID_DESTRUCTOR: int
DISPID_EVALUATE: int
DISPID_NEWENUM: int
DISPID_PROPERTYPUT: int
DISPID_STARTENUM: int
DISPID_THIS: int
DISPID_UNKNOWN: int
DISPID_VALUE: int
DVASPECT_CONTENT: int
DVASPECT_DOCPRINT: int
DVASPECT_ICON: int
DVASPECT_THUMBNAIL: int
EOAC_ACCESS_CONTROL: int
EOAC_ANY_AUTHORITY: int
EOAC_APPID: int
EOAC_AUTO_IMPERSONATE: int
EOAC_DEFAULT: int
EOAC_DISABLE_AAA: int
EOAC_DYNAMIC: int
EOAC_DYNAMIC_CLOAKING: int
EOAC_MAKE_FULLSIC: int
EOAC_MUTUAL_AUTH: int
EOAC_NONE: int
EOAC_NO_CUSTOM_MARSHAL: int
EOAC_REQUIRE_FULLSIC: int
EOAC_SECURE_REFS: int
EOAC_STATIC_CLOAKING: int
EXTCONN_CALLABLE: int
EXTCONN_STRONG: int
EXTCONN_WEAK: int
Empty: _win32typing.PyOleEmpty
FMTID_DocSummaryInformation: _win32typing.PyIID
FMTID_SummaryInformation: _win32typing.PyIID
FMTID_UserDefinedProperties: _win32typing.PyIID
FUNCFLAG_FBINDABLE: int
FUNCFLAG_FDEFAULTBIND: int
FUNCFLAG_FDISPLAYBIND: int
FUNCFLAG_FHIDDEN: int
FUNCFLAG_FREQUESTEDIT: int
FUNCFLAG_FRESTRICTED: int
FUNCFLAG_FSOURCE: int
FUNCFLAG_FUSESGETLASTERROR: int
FUNC_DISPATCH: int
FUNC_NONVIRTUAL: int
FUNC_PUREVIRTUAL: int
FUNC_STATIC: int
FUNC_VIRTUAL: int
IDLFLAG_FIN: int
IDLFLAG_FLCID: int
IDLFLAG_FOUT: int
IDLFLAG_FRETVAL: int
IDLFLAG_NONE: int
IID_IBindCtx: _win32typing.PyIID
IID_ICancelMethodCalls: _win32typing.PyIID
IID_ICatInformation: _win32typing.PyIID
IID_ICatRegister: _win32typing.PyIID
IID_IClassFactory: _win32typing.PyIID
IID_IClientSecurity: _win32typing.PyIID
IID_IConnectionPoint: _win32typing.PyIID
IID_IConnectionPointContainer: _win32typing.PyIID
IID_IContext: _win32typing.PyIID
IID_ICreateTypeInfo: _win32typing.PyIID
IID_ICreateTypeLib: _win32typing.PyIID
IID_ICreateTypeLib2: _win32typing.PyIID
IID_IDataObject: _win32typing.PyIID
IID_IDispatch: _win32typing.PyIID
IID_IDispatchEx: _win32typing.PyIID
IID_IDropSource: _win32typing.PyIID
IID_IDropTarget: _win32typing.PyIID
IID_IEnumCATEGORYINFO: _win32typing.PyIID
IID_IEnumConnectionPoints: _win32typing.PyIID
IID_IEnumConnections: _win32typing.PyIID
IID_IEnumContextProps: _win32typing.PyIID
IID_IEnumFORMATETC: _win32typing.PyIID
IID_IEnumGUID: _win32typing.PyIID
IID_IEnumMoniker: _win32typing.PyIID
IID_IEnumSTATPROPSETSTG: _win32typing.PyIID
IID_IEnumSTATPROPSTG: _win32typing.PyIID
IID_IEnumSTATSTG: _win32typing.PyIID
IID_IEnumString: _win32typing.PyIID
IID_IEnumVARIANT: _win32typing.PyIID
IID_IErrorLog: _win32typing.PyIID
IID_IExternalConnection: _win32typing.PyIID
IID_IGlobalInterfaceTable: _win32typing.PyIID
IID_ILockBytes: _win32typing.PyIID
IID_IMarshal: _win32typing.PyIID
IID_IMoniker: _win32typing.PyIID
IID_IOleWindow: _win32typing.PyIID
IID_IPersist: _win32typing.PyIID
IID_IPersistFile: _win32typing.PyIID
IID_IPersistPropertyBag: _win32typing.PyIID
IID_IPersistStorage: _win32typing.PyIID
IID_IPersistStream: _win32typing.PyIID
IID_IPersistStreamInit: _win32typing.PyIID
IID_IPropertyBag: _win32typing.PyIID
IID_IPropertySetStorage: _win32typing.PyIID
IID_IPropertyStorage: _win32typing.PyIID
IID_IProvideClassInfo: _win32typing.PyIID
IID_IProvideClassInfo2: _win32typing.PyIID
IID_IRunningObjectTable: _win32typing.PyIID
IID_IServerSecurity: _win32typing.PyIID
IID_IServiceProvider: _win32typing.PyIID
IID_IStdMarshalInfo: _win32typing.PyIID
IID_IStorage: _win32typing.PyIID
IID_IStream: _win32typing.PyIID
IID_ITypeComp: _win32typing.PyIID
IID_ITypeInfo: _win32typing.PyIID
IID_ITypeLib: _win32typing.PyIID
IID_IUnknown: _win32typing.PyIID
IID_NULL: _win32typing.PyIID
IID_StdOle: _win32typing.PyIID
IMPLTYPEFLAG_FDEFAULT: int
IMPLTYPEFLAG_FRESTRICTED: int
IMPLTYPEFLAG_FSOURCE: int
INVOKE_FUNC: int
INVOKE_PROPERTYGET: int
INVOKE_PROPERTYPUT: int
INVOKE_PROPERTYPUTREF: int
InterfaceNames: dict[str, _win32typing.PyIID]
MKSYS_ANTIMONIKER: int
MKSYS_CLASSMONIKER: int
MKSYS_FILEMONIKER: int
MKSYS_GENERICCOMPOSITE: int
MKSYS_ITEMMONIKER: int
MKSYS_NONE: int
MKSYS_POINTERMONIKER: int
MSHCTX_DIFFERENTMACHINE: int
MSHCTX_INPROC: int
MSHCTX_LOCAL: int
MSHCTX_NOSHAREDMEM: int
MSHLFLAGS_NOPING: int
MSHLFLAGS_NORMAL: int
MSHLFLAGS_TABLESTRONG: int
MSHLFLAGS_TABLEWEAK: int
Missing: _win32typing.PyOleMissing
Nothing: _win32typing.PyOleNothing
PARAMFLAG_FHASDEFAULT: int
PARAMFLAG_FIN: int
PARAMFLAG_FLCID: int
PARAMFLAG_FOPT: int
PARAMFLAG_FOUT: int
PARAMFLAG_FRETVAL: int
PARAMFLAG_NONE: int
REGCLS_MULTIPLEUSE: int
REGCLS_MULTI_SEPARATE: int
REGCLS_SINGLEUSE: int
REGCLS_SUSPENDED: int
ROTFLAGS_ALLOWANYCLIENT: int
ROTFLAGS_REGISTRATIONKEEPSALIVE: int
RPC_C_AUTHN_DCE_PRIVATE: int
RPC_C_AUTHN_DCE_PUBLIC: int
RPC_C_AUTHN_DEC_PUBLIC: int
RPC_C_AUTHN_DEFAULT: int
RPC_C_AUTHN_DPA: int
RPC_C_AUTHN_GSS_KERBEROS: int
RPC_C_AUTHN_GSS_NEGOTIATE: int
RPC_C_AUTHN_GSS_SCHANNEL: int
RPC_C_AUTHN_LEVEL_CALL: int
RPC_C_AUTHN_LEVEL_CONNECT: int
RPC_C_AUTHN_LEVEL_DEFAULT: int
RPC_C_AUTHN_LEVEL_NONE: int
RPC_C_AUTHN_LEVEL_PKT: int
RPC_C_AUTHN_LEVEL_PKT_INTEGRITY: int
RPC_C_AUTHN_LEVEL_PKT_PRIVACY: int
RPC_C_AUTHN_MQ: int
RPC_C_AUTHN_MSN: int
RPC_C_AUTHN_NONE: int
RPC_C_AUTHN_WINNT: int
RPC_C_AUTHZ_DCE: int
RPC_C_AUTHZ_DEFAULT: int
RPC_C_AUTHZ_NAME: int
RPC_C_AUTHZ_NONE: int
RPC_C_IMP_LEVEL_ANONYMOUS: int
RPC_C_IMP_LEVEL_DEFAULT: int
RPC_C_IMP_LEVEL_DELEGATE: int
RPC_C_IMP_LEVEL_IDENTIFY: int
RPC_C_IMP_LEVEL_IMPERSONATE: int
STDOLE2_LCID: int
STDOLE2_MAJORVERNUM: int
STDOLE2_MINORVERNUM: int
STDOLE_LCID: int
STDOLE_MAJORVERNUM: int
STDOLE_MINORVERNUM: int
STREAM_SEEK_CUR: int
STREAM_SEEK_END: int
STREAM_SEEK_SET: int
SYS_MAC: int
SYS_WIN16: int
SYS_WIN32: int
ServerInterfaces: dict[_win32typing.PyIID, bytes]
TKIND_ALIAS: int
TKIND_COCLASS: int
TKIND_DISPATCH: int
TKIND_ENUM: int
TKIND_INTERFACE: int
TKIND_MODULE: int
TKIND_RECORD: int
TKIND_UNION: int
TYMED_ENHMF: int
TYMED_FILE: int
TYMED_GDI: int
TYMED_HGLOBAL: int
TYMED_ISTORAGE: int
TYMED_ISTREAM: int
TYMED_MFPICT: int
TYMED_NULL: int
TYPEFLAG_FAGGREGATABLE: int
TYPEFLAG_FAPPOBJECT: int
TYPEFLAG_FCANCREATE: int
TYPEFLAG_FCONTROL: int
TYPEFLAG_FDISPATCHABLE: int
TYPEFLAG_FDUAL: int
TYPEFLAG_FHIDDEN: int
TYPEFLAG_FLICENSED: int
TYPEFLAG_FNONEXTENSIBLE: int
TYPEFLAG_FOLEAUTOMATION: int
TYPEFLAG_FPREDECLID: int
TYPEFLAG_FREPLACEABLE: int
TYPEFLAG_FRESTRICTED: int
TYPEFLAG_FREVERSEBIND: int
TypeIIDs: dict[_win32typing.PyIID, type]
URL_MK_LEGACY: int
URL_MK_UNIFORM: int
VARFLAG_FREADONLY: int
VAR_CONST: int
VAR_DISPATCH: int
VAR_PERINSTANCE: int
VAR_STATIC: int
VT_ARRAY: int
VT_BLOB: int
VT_BLOB_OBJECT: int
VT_BOOL: int
VT_BSTR: int
VT_BSTR_BLOB: int
VT_BYREF: int
VT_CARRAY: int
VT_CF: int
VT_CLSID: int
VT_CY: int
VT_DATE: int
VT_DECIMAL: int
VT_DISPATCH: int
VT_EMPTY: int
VT_ERROR: int
VT_FILETIME: int
VT_HRESULT: int
VT_I1: int
VT_I2: int
VT_I4: int
VT_I8: int
VT_ILLEGAL: int
VT_ILLEGALMASKED: int
VT_INT: int
VT_LPSTR: int
VT_LPWSTR: int
VT_NULL: int
VT_PTR: int
VT_R4: int
VT_R8: int
VT_RECORD: int
VT_RESERVED: int
VT_SAFEARRAY: int
VT_STORAGE: int
VT_STORED_OBJECT: int
VT_STREAM: int
VT_STREAMED_OBJECT: int
VT_TYPEMASK: int
VT_UI1: int
VT_UI2: int
VT_UI4: int
VT_UI8: int
VT_UINT: int
VT_UNKNOWN: int
VT_USERDEFINED: int
VT_VARIANT: int
VT_VECTOR: int
VT_VOID: int

dcom: int
fdexNameCaseInsensitive: int
fdexNameCaseSensitive: int
fdexNameEnsure: int
fdexNameImplicit: int
fdexPropCanCall: int
fdexPropCanConstruct: int
fdexPropCanGet: int
fdexPropCanPut: int
fdexPropCanPutRef: int
fdexPropCanSourceEvents: int
fdexPropCannotCall: int
fdexPropCannotConstruct: int
fdexPropCannotGet: int
fdexPropCannotPut: int
fdexPropCannotPutRef: int
fdexPropCannotSourceEvents: int
fdexPropDynamicType: int
fdexPropNoSideEffects: int
frozen: int



language: str
windowmanager: str | None
icon_theme: str
icon_size: int
cache_time: int
root_mode: bool

def setWindowManager(wm: str) -> None: ...
def setIconTheme(theme: str) -> None: ...
def setIconSize(size: int) -> None: ...
def setCacheTime(time: int) -> None: ...
def setLocale(lang: str) -> None: ...
def setRootMode(boolean: bool) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator, Mapping, MutableSet, Reversible

from networkx.classes.digraph import DiGraph
from networkx.classes.graph import _Node
from networkx.utils.backends import _dispatch

__all__ = ["check_planarity", "is_planar", "PlanarEmbedding"]

@_dispatch
def is_planar(G) -> bool: ...
@_dispatch
def check_planarity(G, counterexample: bool = False): ...

class Interval:
    low: Incomplete
    high: Incomplete
    def __init__(self, low: Incomplete | None = None, high: Incomplete | None = None) -> None: ...
    def empty(self): ...
    def copy(self): ...
    def conflicting(self, b, planarity_state): ...

class ConflictPair:
    left: Incomplete
    right: Incomplete
    def __init__(self, left=..., right=...) -> None: ...
    def swap(self) -> None: ...
    def lowest(self, planarity_state): ...

class LRPlanarity:
    G: Incomplete
    roots: Incomplete
    height: Incomplete
    lowpt: Incomplete
    lowpt2: Incomplete
    nesting_depth: Incomplete
    parent_edge: Incomplete
    DG: Incomplete
    adjs: Incomplete
    ordered_adjs: Incomplete
    ref: Incomplete
    side: Incomplete
    S: Incomplete
    stack_bottom: Incomplete
    lowpt_edge: Incomplete
    left_ref: Incomplete
    right_ref: Incomplete
    embedding: Incomplete
    def __init__(self, G) -> None: ...
    def lr_planarity(self): ...
    def lr_planarity_recursive(self): ...
    def dfs_orientation(self, v): ...
    def dfs_orientation_recursive(self, v) -> None: ...
    def dfs_testing(self, v): ...
    def dfs_testing_recursive(self, v): ...
    def add_constraints(self, ei, e): ...
    def remove_back_edges(self, e) -> None: ...
    def dfs_embedding(self, v): ...
    def dfs_embedding_recursive(self, v) -> None: ...
    def sign(self, e): ...
    def sign_recursive(self, e): ...

class PlanarEmbedding(DiGraph[_Node]):
    def get_data(self) -> dict[_Node, list[_Node]]: ...
    def set_data(self, data: Mapping[_Node, Reversible[_Node]]) -> None: ...
    def neighbors_cw_order(self, v: _Node) -> Generator[_Node, None, None]: ...
    def check_structure(self) -> None: ...
    def add_half_edge_ccw(self, start_node: _Node, end_node: _Node, reference_neighbor: _Node) -> None: ...
    def add_half_edge_cw(self, start_node: _Node, end_node: _Node, reference_neighbor: _Node) -> None: ...
    def connect_components(self, v: _Node, w: _Node) -> None: ...
    def add_half_edge_first(self, start_node: _Node, end_node: _Node) -> None: ...
    def next_face_half_edge(self, v: _Node, w: _Node) -> tuple[_Node, _Node]: ...
    def traverse_face(
        self, v: _Node, w: _Node, mark_half_edges: MutableSet[tuple[_Node, _Node]] | None = None
    ) -> list[_Node]: ...



from _typeshed import Incomplete
from typing import ClassVar

from .core import UnitedStates

class Massachusetts(UnitedStates):
    include_patriots_day: ClassVar[bool]

class SuffolkCountyMassachusetts(Massachusetts):
    FIXED_HOLIDAYS: Incomplete



from _typeshed import Incomplete
from typing import Any, ClassVar, Literal
from typing_extensions import TypeAlias

from ._imaging import _PixelAccessor
from .ImageFile import ImageFile

_OleFileIO: TypeAlias = Any  # olefile.OleFileIO
_OleStream: TypeAlias = Any  # olefile.OleStream

MODES: dict[tuple[int, ...], tuple[str, str]]

class FpxImageFile(ImageFile):
    ole: _OleFileIO
    format: ClassVar[Literal["FPX"]]
    format_description: ClassVar[str]
    fp: _OleStream | None
    maxid: int
    rawmode: str
    jpeg: dict[int, Incomplete]
    tile_prefix: Incomplete
    stream: list[str]
    def load(self) -> _PixelAccessor: ...



from _typeshed import Incomplete
from typing import Any

class Prefix:
    bucket: Any
    name: Any
    def __init__(self, bucket: Incomplete | None = None, name: Incomplete | None = None) -> None: ...
    def startElement(self, name, attrs, connection): ...
    def endElement(self, name, value, connection): ...
    @property
    def provider(self): ...



from typing import Final, NoReturn

from Xlib import display
from Xlib.protocol import rq

class CreateWindow(rq.Request): ...
class ChangeWindowAttributes(rq.Request): ...
class GetWindowAttributes(rq.ReplyRequest): ...
class DestroyWindow(rq.Request): ...
class DestroySubWindows(rq.Request): ...
class ChangeSaveSet(rq.Request): ...
class ReparentWindow(rq.Request): ...
class MapWindow(rq.Request): ...
class MapSubwindows(rq.Request): ...
class UnmapWindow(rq.Request): ...
class UnmapSubwindows(rq.Request): ...
class ConfigureWindow(rq.Request): ...
class CirculateWindow(rq.Request): ...
class GetGeometry(rq.ReplyRequest): ...
class QueryTree(rq.ReplyRequest): ...
class InternAtom(rq.ReplyRequest): ...
class GetAtomName(rq.ReplyRequest): ...
class ChangeProperty(rq.Request): ...
class DeleteProperty(rq.Request): ...
class GetProperty(rq.ReplyRequest): ...
class ListProperties(rq.ReplyRequest): ...
class SetSelectionOwner(rq.Request): ...
class GetSelectionOwner(rq.ReplyRequest): ...
class ConvertSelection(rq.Request): ...
class SendEvent(rq.Request): ...
class GrabPointer(rq.ReplyRequest): ...
class UngrabPointer(rq.Request): ...
class GrabButton(rq.Request): ...
class UngrabButton(rq.Request): ...
class ChangeActivePointerGrab(rq.Request): ...
class GrabKeyboard(rq.ReplyRequest): ...
class UngrabKeyboard(rq.Request): ...
class GrabKey(rq.Request): ...
class UngrabKey(rq.Request): ...
class AllowEvents(rq.Request): ...
class GrabServer(rq.Request): ...
class UngrabServer(rq.Request): ...
class QueryPointer(rq.ReplyRequest): ...
class GetMotionEvents(rq.ReplyRequest): ...
class TranslateCoords(rq.ReplyRequest): ...
class WarpPointer(rq.Request): ...
class SetInputFocus(rq.Request): ...
class GetInputFocus(rq.ReplyRequest): ...
class QueryKeymap(rq.ReplyRequest): ...
class OpenFont(rq.Request): ...
class CloseFont(rq.Request): ...
class QueryFont(rq.ReplyRequest): ...
class QueryTextExtents(rq.ReplyRequest): ...
class ListFonts(rq.ReplyRequest): ...

class ListFontsWithInfo(rq.ReplyRequest):
    def __init__(self, display: display.Display, defer: bool = False, *args: object, **keys: object) -> None: ...
    def __getattr__(self, attr: object) -> NoReturn: ...
    def __getitem__(self, item: str) -> object: ...
    def __len__(self) -> int: ...

class SetFontPath(rq.Request): ...
class GetFontPath(rq.ReplyRequest): ...
class CreatePixmap(rq.Request): ...
class FreePixmap(rq.Request): ...
class CreateGC(rq.Request): ...
class ChangeGC(rq.Request): ...
class CopyGC(rq.Request): ...
class SetDashes(rq.Request): ...
class SetClipRectangles(rq.Request): ...
class FreeGC(rq.Request): ...
class ClearArea(rq.Request): ...
class CopyArea(rq.Request): ...
class CopyPlane(rq.Request): ...
class PolyPoint(rq.Request): ...
class PolyLine(rq.Request): ...
class PolySegment(rq.Request): ...
class PolyRectangle(rq.Request): ...
class PolyArc(rq.Request): ...
class FillPoly(rq.Request): ...
class PolyFillRectangle(rq.Request): ...
class PolyFillArc(rq.Request): ...
class PutImage(rq.Request): ...
class GetImage(rq.ReplyRequest): ...
class PolyText8(rq.Request): ...
class PolyText16(rq.Request): ...
class ImageText8(rq.Request): ...
class ImageText16(rq.Request): ...
class CreateColormap(rq.Request): ...
class FreeColormap(rq.Request): ...
class CopyColormapAndFree(rq.Request): ...
class InstallColormap(rq.Request): ...
class UninstallColormap(rq.Request): ...
class ListInstalledColormaps(rq.ReplyRequest): ...
class AllocColor(rq.ReplyRequest): ...
class AllocNamedColor(rq.ReplyRequest): ...
class AllocColorCells(rq.ReplyRequest): ...
class AllocColorPlanes(rq.ReplyRequest): ...
class FreeColors(rq.Request): ...
class StoreColors(rq.Request): ...
class StoreNamedColor(rq.Request): ...
class QueryColors(rq.ReplyRequest): ...
class LookupColor(rq.ReplyRequest): ...
class CreateCursor(rq.Request): ...
class CreateGlyphCursor(rq.Request): ...
class FreeCursor(rq.Request): ...
class RecolorCursor(rq.Request): ...
class QueryBestSize(rq.ReplyRequest): ...
class QueryExtension(rq.ReplyRequest): ...
class ListExtensions(rq.ReplyRequest): ...
class ChangeKeyboardMapping(rq.Request): ...
class GetKeyboardMapping(rq.ReplyRequest): ...
class ChangeKeyboardControl(rq.Request): ...
class GetKeyboardControl(rq.ReplyRequest): ...
class Bell(rq.Request): ...
class ChangePointerControl(rq.Request): ...
class GetPointerControl(rq.ReplyRequest): ...
class SetScreenSaver(rq.Request): ...
class GetScreenSaver(rq.ReplyRequest): ...
class ChangeHosts(rq.Request): ...
class ListHosts(rq.ReplyRequest): ...
class SetAccessControl(rq.Request): ...
class SetCloseDownMode(rq.Request): ...
class KillClient(rq.Request): ...
class RotateProperties(rq.Request): ...
class ForceScreenSaver(rq.Request): ...
class SetPointerMapping(rq.ReplyRequest): ...
class GetPointerMapping(rq.ReplyRequest): ...
class SetModifierMapping(rq.ReplyRequest): ...
class GetModifierMapping(rq.ReplyRequest): ...
class NoOperation(rq.Request): ...

major_codes: Final[dict[int, type[rq.Request]]]



import sys
from collections.abc import Callable, Mapping
from socket import socket
from threading import Lock
from typing import Literal

from waitress import wasyncore as wasyncore

class _triggerbase:
    kind: str | None
    lock: Lock
    thunks: Callable[[None], None]
    def readable(self) -> Literal[True]: ...
    def writable(self) -> Literal[False]: ...
    def handle_connect(self) -> None: ...
    def handle_close(self) -> None: ...
    def close(self) -> None: ...
    def pull_trigger(self, thunk: Callable[[None], object] | None = None) -> None: ...
    def handle_read(self) -> None: ...

if sys.platform != "win32":
    class trigger(_triggerbase, wasyncore.file_dispatcher):
        kind: str
        def __init__(self, map: Mapping[str, _triggerbase]) -> None: ...

else:
    class trigger(_triggerbase, wasyncore.dispatcher):
        kind: str
        trigger: socket
        def __init__(self, map: Mapping[str, _triggerbase]) -> None: ...



from _typeshed import Incomplete

from antlr4.Token import Token as Token
from antlr4.tree.Tree import (
    ErrorNode as ErrorNode,
    ParseTree as ParseTree,
    RuleNode as RuleNode,
    TerminalNode as TerminalNode,
    Tree as Tree,
)
from antlr4.Utils import escapeWhitespace as escapeWhitespace

Parser: Incomplete

class Trees:
    @classmethod
    def toStringTree(cls, t: Tree, ruleNames: list[str] | None = None, recog: Parser | None = None): ...
    @classmethod
    def getNodeText(cls, t: Tree, ruleNames: list[str] | None = None, recog: Parser | None = None): ...
    @classmethod
    def getChildren(cls, t: Tree): ...
    @classmethod
    def getAncestors(cls, t: Tree): ...
    @classmethod
    def findAllTokenNodes(cls, t: ParseTree, ttype: int): ...
    @classmethod
    def findAllRuleNodes(cls, t: ParseTree, ruleIndex: int): ...
    @classmethod
    def findAllNodes(cls, t: ParseTree, index: int, findTokens: bool): ...
    @classmethod
    def descendants(cls, t: ParseTree): ...



from typing import Final

XK_Aogonek: Final = 0x1A1
XK_breve: Final = 0x1A2
XK_Lstroke: Final = 0x1A3
XK_Lcaron: Final = 0x1A5
XK_Sacute: Final = 0x1A6
XK_Scaron: Final = 0x1A9
XK_Scedilla: Final = 0x1AA
XK_Tcaron: Final = 0x1AB
XK_Zacute: Final = 0x1AC
XK_Zcaron: Final = 0x1AE
XK_Zabovedot: Final = 0x1AF
XK_aogonek: Final = 0x1B1
XK_ogonek: Final = 0x1B2
XK_lstroke: Final = 0x1B3
XK_lcaron: Final = 0x1B5
XK_sacute: Final = 0x1B6
XK_caron: Final = 0x1B7
XK_scaron: Final = 0x1B9
XK_scedilla: Final = 0x1BA
XK_tcaron: Final = 0x1BB
XK_zacute: Final = 0x1BC
XK_doubleacute: Final = 0x1BD
XK_zcaron: Final = 0x1BE
XK_zabovedot: Final = 0x1BF
XK_Racute: Final = 0x1C0
XK_Abreve: Final = 0x1C3
XK_Lacute: Final = 0x1C5
XK_Cacute: Final = 0x1C6
XK_Ccaron: Final = 0x1C8
XK_Eogonek: Final = 0x1CA
XK_Ecaron: Final = 0x1CC
XK_Dcaron: Final = 0x1CF
XK_Dstroke: Final = 0x1D0
XK_Nacute: Final = 0x1D1
XK_Ncaron: Final = 0x1D2
XK_Odoubleacute: Final = 0x1D5
XK_Rcaron: Final = 0x1D8
XK_Uring: Final = 0x1D9
XK_Udoubleacute: Final = 0x1DB
XK_Tcedilla: Final = 0x1DE
XK_racute: Final = 0x1E0
XK_abreve: Final = 0x1E3
XK_lacute: Final = 0x1E5
XK_cacute: Final = 0x1E6
XK_ccaron: Final = 0x1E8
XK_eogonek: Final = 0x1EA
XK_ecaron: Final = 0x1EC
XK_dcaron: Final = 0x1EF
XK_dstroke: Final = 0x1F0
XK_nacute: Final = 0x1F1
XK_ncaron: Final = 0x1F2
XK_odoubleacute: Final = 0x1F5
XK_udoubleacute: Final = 0x1FB
XK_rcaron: Final = 0x1F8
XK_uring: Final = 0x1F9
XK_tcedilla: Final = 0x1FE
XK_abovedot: Final = 0x1FF



from collections.abc import Callable
from gettext import NullTranslations
from typing import Any, Protocol
from typing_extensions import Self

class _TranslationStringFactory(Protocol):
    def __call__(
        self,
        msgid: str | TranslationString,
        mapping: dict[str, Any] | None = ...,
        default: str | None = ...,
        context: str | None = ...,
    ) -> TranslationString: ...

class _ChameleonTranslate(Protocol):
    def __call__(
        self,
        msgid: str | TranslationString,
        mapping: dict[str, Any] | None = ...,
        context: str | None = ...,
        target_language: str | None = ...,
        default: str | None = ...,
    ) -> TranslationString: ...

class _TranslatorPolicy(Protocol):
    def __call__(self, translations: NullTranslations, tstring: str, domain: str | None, context: str | None) -> str: ...

class _Translator(Protocol):
    def __call__(
        self,
        tstring: str | TranslationString,
        domain: str | None = None,
        mapping: dict[str, Any] | None = None,
        context: str | None = None,
    ) -> str: ...

class _PluralizerPolicy(Protocol):
    def __call__(
        self, translations: NullTranslations, singular: str, plural: str, n: int, domain: str | None, context: str | None
    ) -> str: ...

class _Pluralizer(Protocol):
    def __call__(
        self,
        singular: str | TranslationString,
        plural: str | TranslationString,
        n: int,
        domain: str | None = None,
        mapping: dict[str, Any] | None = None,
        context: str | None = None,
    ) -> str: ...

class TranslationString(str):
    domain: str | None
    context: str | None
    default: str
    mapping: dict[str, Any] | None
    def __new__(
        self,
        msgid: str | Self,
        domain: str | None = None,
        default: str | None = None,
        mapping: dict[str, Any] | None = None,
        context: str | None = None,
    ) -> Self: ...
    def __mod__(self, options: dict[str, Any]) -> TranslationString: ...  # type: ignore[override]
    def interpolate(self, translated: str | None = None) -> str: ...
    def __reduce__(self) -> tuple[type[Self], tuple[str, str | None, str, dict[str, Any], str | None]]: ...

def TranslationStringFactory(factory_domain: str) -> _TranslationStringFactory: ...
def ChameleonTranslate(translator: Callable[[TranslationString], str] | None) -> _ChameleonTranslate: ...
def ugettext_policy(translations: NullTranslations, tstring: str, domain: str | None, context: str | None) -> str: ...
def dugettext_policy(translations: NullTranslations, tstring: str, domain: str | None, context: str | None) -> str: ...
def Translator(translations: NullTranslations | None = None, policy: _TranslatorPolicy | None = None) -> _Translator: ...
def ungettext_policy(
    translations: NullTranslations, singular: str, plural: str, n: int, domain: str | None, context: str | None
) -> str: ...
def dungettext_policy(
    translations: NullTranslations, singular: str, plural: str, n: int, domain: str | None, context: str | None
) -> str: ...
def Pluralizer(translations: NullTranslations | None = None, policy: _PluralizerPolicy | None = None) -> _Pluralizer: ...



from qrcode import image as image
from qrcode.constants import (
    ERROR_CORRECT_H as ERROR_CORRECT_H,
    ERROR_CORRECT_L as ERROR_CORRECT_L,
    ERROR_CORRECT_M as ERROR_CORRECT_M,
    ERROR_CORRECT_Q as ERROR_CORRECT_Q,
)
from qrcode.main import make as make

def run_example(data: str = "http://www.lincolnloop.com", *args, **kwargs) -> None: ...



from collections.abc import Generator, Iterable, Sequence
from importlib.machinery import ModuleSpec
from types import ModuleType

class VendorImporter:
    root_name: str
    vendored_names: set[str]
    vendor_pkg: str
    def __init__(self, root_name: str, vendored_names: Iterable[str] = (), vendor_pkg: str | None = None) -> None: ...
    @property
    def search_path(self) -> Generator[str, None, None]: ...
    def load_module(self, fullname: str) -> ModuleType: ...
    def create_module(self, spec: ModuleSpec) -> ModuleType: ...
    def exec_module(self, module: ModuleType) -> None: ...
    def find_spec(
        self, fullname: str, path: Sequence[str] | None = None, target: ModuleType | None = None
    ) -> ModuleSpec | None: ...
    def install(self) -> None: ...

names: tuple[str, ...]



from typing import ClassVar

from .core import UnitedStates

class Mississippi(UnitedStates):
    include_thanksgiving_friday: ClassVar[bool]
    include_confederation_day: ClassVar[bool]
    include_columbus_day: ClassVar[bool]
    martin_luther_king_label: ClassVar[str]
    veterans_day_label: ClassVar[str]
    national_memorial_day_label: ClassVar[str]



from _typeshed import Incomplete, SupportsKeysAndGetItem
from collections.abc import Callable, Generator, Iterable, Iterator, Mapping
from contextlib import contextmanager
from typing import Any, ClassVar
from typing_extensions import TypeAlias

from referencing.jsonschema import Schema, SchemaRegistry
from referencing.typing import URI

from ._format import FormatChecker
from ._types import TypeChecker
from ._utils import Unset, URIDict
from .exceptions import ValidationError

# these type aliases do not exist at runtime, they're only defined here in the stub
_JsonObject: TypeAlias = Mapping[str, Any]
_JsonValue: TypeAlias = _JsonObject | list[Any] | str | int | float | bool | None
_ValidatorCallback: TypeAlias = Callable[[Any, Any, _JsonValue, _JsonObject], Iterator[ValidationError]]

# This class does not exist at runtime. Compatible classes are created at
# runtime by create().
class _Validator:
    VALIDATORS: ClassVar[dict[Incomplete, Incomplete]]
    META_SCHEMA: ClassVar[dict[Incomplete, Incomplete]]
    TYPE_CHECKER: ClassVar[Incomplete]
    FORMAT_CHECKER: ClassVar[Incomplete]
    @staticmethod
    def ID_OF(contents: Schema) -> URI | None: ...
    schema: Schema
    format_checker: FormatChecker | None
    def __init__(
        self,
        schema: Schema,
        resolver: Incomplete | None = None,
        format_checker: FormatChecker | None = None,
        *,
        registry: SchemaRegistry = ...,
        _resolver: Incomplete | None = None,
    ) -> None: ...
    @classmethod
    def check_schema(cls, schema: Schema, format_checker: FormatChecker | Unset = ...) -> None: ...
    @property
    def resolver(self): ...
    def evolve(self, **changes) -> _Validator: ...
    def iter_errors(self, instance, _schema: Schema | None = ...) -> Generator[Incomplete, None, None]: ...
    def descend(
        self,
        instance,
        schema: Schema,
        path: Incomplete | None = ...,
        schema_path: Incomplete | None = ...,
        resolver: Incomplete | None = None,
    ) -> Generator[Incomplete, None, None]: ...
    def validate(self, *args, **kwargs) -> None: ...
    def is_type(self, instance, type): ...
    def is_valid(self, instance, _schema: Schema | None = ...) -> bool: ...

def validates(version: str) -> Callable[..., Incomplete]: ...
def create(
    meta_schema: Schema,
    validators: Mapping[str, _ValidatorCallback] | tuple[()] = (),
    version: Incomplete | None = None,
    type_checker: TypeChecker = ...,
    format_checker: FormatChecker = ...,
    id_of: Callable[[Schema], str] = ...,
    applicable_validators: Callable[[Schema], Iterable[tuple[str, _ValidatorCallback]]] = ...,
) -> type[_Validator]: ...
def extend(
    validator,
    validators=(),
    version: Incomplete | None = None,
    type_checker: Incomplete | None = None,
    format_checker: Incomplete | None = None,
): ...

# At runtime these are fields that are assigned the return values of create() calls.
class Draft3Validator(_Validator): ...
class Draft4Validator(_Validator): ...
class Draft6Validator(_Validator): ...
class Draft7Validator(_Validator): ...
class Draft201909Validator(_Validator): ...
class Draft202012Validator(_Validator): ...

_Handler: TypeAlias = Callable[[str], Incomplete]

class RefResolver:
    referrer: dict[str, Incomplete]
    cache_remote: Incomplete
    handlers: dict[str, _Handler]
    store: URIDict
    def __init__(
        self,
        base_uri: str,
        referrer: dict[str, Incomplete],
        store: SupportsKeysAndGetItem[str, str] | Iterable[tuple[str, str]] = ...,
        cache_remote: bool = True,
        handlers: SupportsKeysAndGetItem[str, _Handler] | Iterable[tuple[str, _Handler]] = (),
        urljoin_cache: Incomplete | None = None,
        remote_cache: Incomplete | None = None,
    ) -> None: ...
    @classmethod
    def from_schema(cls, schema: Schema, id_of=..., *args, **kwargs): ...
    def push_scope(self, scope) -> None: ...
    def pop_scope(self) -> None: ...
    @property
    def resolution_scope(self): ...
    @property
    def base_uri(self): ...
    @contextmanager
    def in_scope(self, scope) -> Generator[None, None, None]: ...
    @contextmanager
    def resolving(self, ref) -> Generator[Incomplete, None, None]: ...
    def resolve(self, ref): ...
    def resolve_from_url(self, url): ...
    def resolve_fragment(self, document, fragment): ...
    def resolve_remote(self, uri): ...

def validate(instance: object, schema: Schema, cls: type[_Validator] | None = None, *args: Any, **kwargs: Any) -> None: ...
def validator_for(schema: Schema | bool, default=...): ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Protocol Buffers - Google's data interchange format
Copyright 2008 Google Inc.  All rights reserved.
https://developers.google.com/protocol-buffers/

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.
    * Neither the name of Google Inc. nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""
import builtins
import collections.abc
import typing as typing_extensions

import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.source_context_pb2
import google.protobuf.type_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Api(google.protobuf.message.Message):
    """Api is a light-weight descriptor for an API Interface.

    Interfaces are also described as "protocol buffer services" in some contexts,
    such as by the "service" keyword in a .proto file, but they are different
    from API Services, which represent a concrete implementation of an interface
    as opposed to simply a description of methods and bindings. They are also
    sometimes simply referred to as "APIs" in other contexts, such as the name of
    this message itself. See https://cloud.google.com/apis/design/glossary for
    detailed terminology.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    METHODS_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    SOURCE_CONTEXT_FIELD_NUMBER: builtins.int
    MIXINS_FIELD_NUMBER: builtins.int
    SYNTAX_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The fully qualified name of this interface, including package name
    followed by the interface's simple name.
    """
    @property
    def methods(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Method]:
        """The methods of this interface, in unspecified order."""
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.type_pb2.Option]:
        """Any metadata attached to the interface."""
    version: builtins.str
    """A version string for this interface. If specified, must have the form
    `major-version.minor-version`, as in `1.10`. If the minor version is
    omitted, it defaults to zero. If the entire version field is empty, the
    major version is derived from the package name, as outlined below. If the
    field is not empty, the version in the package name will be verified to be
    consistent with what is provided here.

    The versioning schema uses [semantic
    versioning](http://semver.org) where the major version number
    indicates a breaking change and the minor version an additive,
    non-breaking change. Both version numbers are signals to users
    what to expect from different versions, and should be carefully
    chosen based on the product plan.

    The major version is also reflected in the package name of the
    interface, which must end in `v<major-version>`, as in
    `google.feature.v1`. For major versions 0 and 1, the suffix can
    be omitted. Zero major versions must only be used for
    experimental, non-GA interfaces.
    """
    @property
    def source_context(self) -> google.protobuf.source_context_pb2.SourceContext:
        """Source context for the protocol buffer service represented by this
        message.
        """
    @property
    def mixins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Mixin]:
        """Included interfaces. See [Mixin][]."""
    syntax: google.protobuf.type_pb2.Syntax.ValueType
    """The source syntax of the service."""
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        methods: collections.abc.Iterable[global___Method] | None = ...,
        options: collections.abc.Iterable[google.protobuf.type_pb2.Option] | None = ...,
        version: builtins.str | None = ...,
        source_context: google.protobuf.source_context_pb2.SourceContext | None = ...,
        mixins: collections.abc.Iterable[global___Mixin] | None = ...,
        syntax: google.protobuf.type_pb2.Syntax.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_context", b"source_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["methods", b"methods", "mixins", b"mixins", "name", b"name", "options", b"options", "source_context", b"source_context", "syntax", b"syntax", "version", b"version"]) -> None: ...

global___Api = Api

@typing_extensions.final
class Method(google.protobuf.message.Message):
    """Method represents a method of an API interface."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    REQUEST_TYPE_URL_FIELD_NUMBER: builtins.int
    REQUEST_STREAMING_FIELD_NUMBER: builtins.int
    RESPONSE_TYPE_URL_FIELD_NUMBER: builtins.int
    RESPONSE_STREAMING_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    SYNTAX_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The simple name of this method."""
    request_type_url: builtins.str
    """A URL of the input message type."""
    request_streaming: builtins.bool
    """If true, the request is streamed."""
    response_type_url: builtins.str
    """The URL of the output message type."""
    response_streaming: builtins.bool
    """If true, the response is streamed."""
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[google.protobuf.type_pb2.Option]:
        """Any metadata attached to the method."""
    syntax: google.protobuf.type_pb2.Syntax.ValueType
    """The source syntax of this method."""
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        request_type_url: builtins.str | None = ...,
        request_streaming: builtins.bool | None = ...,
        response_type_url: builtins.str | None = ...,
        response_streaming: builtins.bool | None = ...,
        options: collections.abc.Iterable[google.protobuf.type_pb2.Option] | None = ...,
        syntax: google.protobuf.type_pb2.Syntax.ValueType | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "options", b"options", "request_streaming", b"request_streaming", "request_type_url", b"request_type_url", "response_streaming", b"response_streaming", "response_type_url", b"response_type_url", "syntax", b"syntax"]) -> None: ...

global___Method = Method

@typing_extensions.final
class Mixin(google.protobuf.message.Message):
    """Declares an API Interface to be included in this interface. The including
    interface must redeclare all the methods from the included interface, but
    documentation and options are inherited as follows:

    - If after comment and whitespace stripping, the documentation
      string of the redeclared method is empty, it will be inherited
      from the original method.

    - Each annotation belonging to the service config (http,
      visibility) which is not set in the redeclared method will be
      inherited.

    - If an http annotation is inherited, the path pattern will be
      modified as follows. Any version prefix will be replaced by the
      version of the including interface plus the [root][] path if
      specified.

    Example of a simple mixin:

        package google.acl.v1;
        service AccessControl {
          // Get the underlying ACL object.
          rpc GetAcl(GetAclRequest) returns (Acl) {
            option (google.api.http).get = "/v1/{resource=**}:getAcl";
          }
        }

        package google.storage.v2;
        service Storage {
          rpc GetAcl(GetAclRequest) returns (Acl);

          // Get a data record.
          rpc GetData(GetDataRequest) returns (Data) {
            option (google.api.http).get = "/v2/{resource=**}";
          }
        }

    Example of a mixin configuration:

        apis:
        - name: google.storage.v2.Storage
          mixins:
          - name: google.acl.v1.AccessControl

    The mixin construct implies that all methods in `AccessControl` are
    also declared with same name and request/response types in
    `Storage`. A documentation generator or annotation processor will
    see the effective `Storage.GetAcl` method after inheriting
    documentation and annotations as follows:

        service Storage {
          // Get the underlying ACL object.
          rpc GetAcl(GetAclRequest) returns (Acl) {
            option (google.api.http).get = "/v2/{resource=**}:getAcl";
          }
          ...
        }

    Note how the version in the path pattern changed from `v1` to `v2`.

    If the `root` field in the mixin is specified, it should be a
    relative path under which inherited HTTP paths are placed. Example:

        apis:
        - name: google.storage.v2.Storage
          mixins:
          - name: google.acl.v1.AccessControl
            root: acls

    This implies the following inherited HTTP annotation:

        service Storage {
          // Get the underlying ACL object.
          rpc GetAcl(GetAclRequest) returns (Acl) {
            option (google.api.http).get = "/v2/acls/{resource=**}:getAcl";
          }
          ...
        }
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The fully qualified name of the interface which is included."""
    root: builtins.str
    """If non-empty specifies a path under which inherited HTTP paths
    are rooted.
    """
    def __init__(
        self,
        *,
        name: builtins.str | None = ...,
        root: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "root", b"root"]) -> None: ...

global___Mixin = Mixin



import gdb
from gdb import Frame, UnwindInfo

class Unwinder:
    name: str
    enabled: bool

    def __init__(self, name: str) -> None: ...
    def __call__(self, pending_frame: Frame) -> UnwindInfo | None: ...

def register_unwinder(locus: gdb.Objfile | gdb.Progspace | None, unwinder: Unwinder, replace: bool = ...) -> None: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import ChineseNewYearCalendar, IslamicMixin, WesternMixin

class Philippines(WesternMixin, IslamicMixin, ChineseNewYearCalendar):
    include_labour_day: ClassVar[bool]
    include_new_years_eve: ClassVar[bool]
    include_holy_thursday: ClassVar[bool]
    holy_thursday_label: ClassVar[str]
    include_good_friday: ClassVar[bool]
    include_easter_saturday: ClassVar[bool]
    include_easter_sunday: ClassVar[bool]
    easter_saturday_label: ClassVar[str]
    include_all_saints: ClassVar[bool]
    include_all_souls: ClassVar[bool]
    include_immaculate_conception: ClassVar[bool]
    include_christmas_eve: ClassVar[bool]
    include_eid_al_fitr: ClassVar[bool]
    eid_al_fitr_label: ClassVar[str]
    include_eid_al_adha: ClassVar[bool]
    day_of_sacrifice_label: ClassVar[str]
    WEEKEND_DAYS: Incomplete
    FIXED_HOLIDAYS: Incomplete



from parsimonious.expressions import Expression
from parsimonious.grammar import LazyReference
from parsimonious.nodes import Node
from parsimonious.utils import StrAndRepr

class ParseError(StrAndRepr, Exception):
    text: str
    pos: int
    expr: Expression | None
    def __init__(self, text: str, pos: int = -1, expr: Expression | None = None) -> None: ...
    def line(self) -> int: ...
    def column(self) -> int: ...

class LeftRecursionError(ParseError): ...
class IncompleteParseError(ParseError): ...

class VisitationError(Exception):
    original_class: type[BaseException]
    def __init__(self, exc: BaseException, exc_class: type[BaseException], node: Node) -> None: ...

class BadGrammar(StrAndRepr, Exception): ...

class UndefinedLabel(BadGrammar):
    label: LazyReference
    def __init__(self, label: LazyReference) -> None: ...



from _typeshed import Incomplete

class TemplateChart:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        x_pos: Incomplete | None = None,
        y_pos: Incomplete | None = None,
        height: Incomplete | None = None,
        width: Incomplete | None = None,
        properties: Incomplete | None = None,
    ) -> None: ...
    @property
    def x_pos(self): ...
    @x_pos.setter
    def x_pos(self, x_pos) -> None: ...
    @property
    def y_pos(self): ...
    @y_pos.setter
    def y_pos(self, y_pos) -> None: ...
    @property
    def height(self): ...
    @height.setter
    def height(self, height) -> None: ...
    @property
    def width(self): ...
    @width.setter
    def width(self, width) -> None: ...
    @property
    def properties(self): ...
    @properties.setter
    def properties(self, properties) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from xml.etree.ElementTree import Element

from markdown.blockprocessors import BlockProcessor
from markdown.extensions import Extension
from markdown.postprocessors import RawHtmlPostprocessor

class MarkdownInHtmlProcessor(BlockProcessor):
    def parse_element_content(self, element: Element) -> None: ...

class MarkdownInHTMLPostprocessor(RawHtmlPostprocessor):
    def stash_to_string(self, text: str | Element) -> str: ...

class MarkdownInHtmlExtension(Extension): ...

def makeExtension(**kwargs) -> MarkdownInHtmlExtension: ...



from collections.abc import Iterator
from re import Pattern
from typing import Any, Generic, TypedDict, TypeVar, overload

from markdown.core import Markdown

_T = TypeVar("_T")

BLOCK_LEVEL_ELEMENTS: list[str]
STX: str
ETX: str
INLINE_PLACEHOLDER_PREFIX: str
INLINE_PLACEHOLDER: str
INLINE_PLACEHOLDER_RE: Pattern[str]
AMP_SUBSTITUTE: str
HTML_PLACEHOLDER: str
HTML_PLACEHOLDER_RE: Pattern[str]
TAG_PLACEHOLDER: str
RTL_BIDI_RANGES: Any

def get_installed_extensions(): ...
def deprecated(message: str, stacklevel: int = 2): ...
@overload
def parseBoolValue(value: str) -> bool: ...
@overload
def parseBoolValue(value: str | None, fail_on_errors: bool = True, preserve_none: bool = False) -> bool | None: ...
def code_escape(text: str) -> str: ...
def nearing_recursion_limit() -> bool: ...

class AtomicString(str): ...

class Processor:
    md: Markdown
    def __init__(self, md: Markdown | None = None) -> None: ...

class _TagData(TypedDict):
    tag: str
    attrs: dict[str, str]
    left_index: int
    right_index: int

class HtmlStash:
    html_counter: int
    rawHtmlBlocks: list[str]
    tag_counter: int
    tag_data: list[_TagData]
    def __init__(self) -> None: ...
    def store(self, html: str) -> str: ...
    def reset(self) -> None: ...
    def get_placeholder(self, key: int) -> str: ...
    def store_tag(self, tag: str, attrs: dict[str, str], left_index: int, right_index: int) -> str: ...

class Registry(Generic[_T]):
    def __init__(self) -> None: ...
    def __contains__(self, item: str | _T) -> bool: ...
    def __iter__(self) -> Iterator[_T]: ...
    @overload
    def __getitem__(self, key: slice) -> Registry[_T]: ...
    @overload
    def __getitem__(self, key: str | int) -> _T: ...
    def __len__(self) -> int: ...
    def get_index_for_name(self, name: str) -> int: ...
    def register(self, item: _T, name: str, priority: float) -> None: ...
    def deregister(self, name: str, strict: bool = True) -> None: ...



from typing import ClassVar

from pyasn1.codec.ber import encoder
from pyasn1.type.tag import TagSet

__all__ = ["Encoder", "encode"]

class BooleanEncoder(encoder.IntegerEncoder):
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class RealEncoder(encoder.RealEncoder): ...

class TimeEncoderMixIn:
    Z_CHAR: ClassVar[int]
    PLUS_CHAR: ClassVar[int]
    MINUS_CHAR: ClassVar[int]
    COMMA_CHAR: ClassVar[int]
    DOT_CHAR: ClassVar[int]
    ZERO_CHAR: ClassVar[int]
    MIN_LENGTH: ClassVar[int]
    MAX_LENGTH: ClassVar[int]
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class GeneralizedTimeEncoder(TimeEncoderMixIn, encoder.OctetStringEncoder): ...
class UTCTimeEncoder(TimeEncoderMixIn, encoder.OctetStringEncoder): ...

class SetOfEncoder(encoder.SequenceOfEncoder):
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class SequenceOfEncoder(encoder.SequenceOfEncoder):
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class SetEncoder(encoder.SequenceEncoder):
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class SequenceEncoder(encoder.SequenceEncoder):
    omitEmptyOptionals: bool

TAG_MAP: dict[TagSet, encoder.AbstractItemEncoder]
TYPE_MAP: dict[int, encoder.AbstractItemEncoder]
# deprecated aliases
tagMap = TAG_MAP
typeMap = TYPE_MAP

class SingleItemEncoder(encoder.SingleItemEncoder):
    fixedDefLengthMode: bool
    fixedChunkSize: int

    TAG_MAP: dict[TagSet, encoder.AbstractItemEncoder]
    TYPE_MAP: dict[int, encoder.AbstractItemEncoder]

class Encoder(encoder.Encoder):
    SINGLE_ITEM_ENCODER: type[SingleItemEncoder]

encode: Encoder



from collections.abc import Callable
from typing_extensions import TypeAlias

from google.protobuf.descriptor import FieldDescriptor

_Sizer: TypeAlias = Callable[[int, bool, bool], int]

Int32Sizer: _Sizer
UInt32Sizer: _Sizer
SInt32Sizer: _Sizer
Fixed32Sizer: _Sizer
Fixed64Sizer: _Sizer
BoolSizer: _Sizer

def StringSizer(field_number: int, is_repeated: bool, is_packed: bool) -> _Sizer: ...
def BytesSizer(field_number: int, is_repeated: bool, is_packed: bool) -> _Sizer: ...
def GroupSizer(field_number: int, is_repeated: bool, is_packed: bool) -> _Sizer: ...
def MessageSizer(field_number: int, is_repeated: bool, is_packed: bool) -> _Sizer: ...
def MessageSetItemSizer(field_number: int) -> _Sizer: ...
def MapSizer(field_descriptor: FieldDescriptor, is_message_map: bool) -> _Sizer: ...
def TagBytes(field_number: int, wire_type: int) -> bytes: ...

_Encoder: TypeAlias = Callable[[Callable[[bytes], int], bytes, bool], int]

Int32Encoder: _Encoder
UInt32Encoder: _Encoder
SInt32Encoder: _Encoder
Fixed32Encoder: _Encoder
Fixed64Encoder: _Encoder
SFixed32Encoder: _Encoder
SFixed64Encoder: _Encoder
FloatEncoder: _Encoder
DoubleEncoder: _Encoder

def BoolEncoder(field_number: int, is_repeated: bool, is_packed: bool) -> _Encoder: ...
def StringEncoder(field_number: int, is_repeated: bool, is_packed: bool) -> _Encoder: ...
def BytesEncoder(field_number: int, is_repeated: bool, is_packed: bool) -> _Encoder: ...
def GroupEncoder(field_number: int, is_repeated: bool, is_packed: bool) -> _Encoder: ...
def MessageEncoder(field_number: int, is_repeated: bool, is_packed: bool) -> _Encoder: ...
def MessageSetItemEncoder(field_number: int) -> _Encoder: ...
def MapEncoder(field_descriptor: FieldDescriptor) -> _Encoder: ...



import re
from _typeshed import StrPath
from typing import Literal

from xdg.IniFile import IniFile

class DesktopEntry(IniFile):
    defaultGroup: str
    content: dict[str, dict[str, str]]
    def __init__(self, filename: StrPath | None = None) -> None: ...
    def parse(self, file: StrPath) -> None: ...  # type: ignore[override]
    def findTryExec(self) -> str | None: ...
    def getType(self) -> str: ...
    def getVersion(self) -> float: ...
    def getVersionString(self) -> str: ...
    def getName(self) -> str: ...
    def getGenericName(self) -> str: ...
    def getNoDisplay(self) -> bool: ...
    def getComment(self) -> str: ...
    def getIcon(self) -> str: ...
    def getHidden(self) -> bool: ...
    def getOnlyShowIn(self) -> list[str]: ...
    def getNotShowIn(self) -> list[str]: ...
    def getTryExec(self) -> str: ...
    def getExec(self) -> str: ...
    def getPath(self) -> str: ...
    def getTerminal(self) -> bool: ...
    def getMimeType(self) -> list[re.Pattern[str]]: ...
    def getMimeTypes(self) -> list[str]: ...
    def getCategories(self) -> list[str]: ...
    def getStartupNotify(self) -> bool: ...
    def getStartupWMClass(self) -> str: ...
    def getURL(self) -> str: ...
    def getServiceTypes(self) -> list[str]: ...
    def getDocPath(self) -> str: ...
    def getKeywords(self) -> list[str]: ...
    def getInitialPreference(self) -> str: ...
    def getDev(self) -> str: ...
    def getFSType(self) -> str: ...
    def getMountPoint(self) -> str: ...
    def getReadonly(self) -> bool: ...
    def getUnmountIcon(self) -> str: ...
    def getMiniIcon(self) -> str: ...
    def getTerminalOptions(self) -> str: ...
    def getDefaultApp(self) -> str: ...
    def getProtocols(self) -> list[str]: ...
    def getExtensions(self) -> list[str]: ...
    def getBinaryPattern(self) -> str: ...
    def getMapNotify(self) -> str: ...
    def getEncoding(self) -> str: ...
    def getSwallowTitle(self) -> str: ...
    def getSwallowExec(self) -> str: ...
    def getSortOrder(self) -> list[str]: ...
    def getFilePattern(self) -> re.Pattern[str]: ...
    def getActions(self) -> list[str]: ...
    filename: str
    def new(self, filename: str) -> None: ...
    type: Literal["Application", "Directory"]
    name: str
    def checkExtras(self) -> None: ...
    def checkGroup(self, group: str) -> None: ...
    def checkKey(self, key: str, value: str, group: str) -> None: ...
    def checkType(self, key: str, type: str) -> None: ...
    def checkOnlyShowIn(self, value: str) -> None: ...
    def checkCategories(self, value: str) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def asyn_lpa_communities(
    G, weight: Incomplete | None = None, seed: Incomplete | None = None
) -> Generator[Incomplete, Incomplete, None]: ...
@_dispatch
def label_propagation_communities(G): ...



from collections.abc import Iterable, Iterator
from typing import Any, Generic, TypeVar

from psycopg2._psycopg import connection, cursor

_T = TypeVar("_T")

class Composable:
    def __init__(self, wrapped: Any) -> None: ...
    def as_string(self, context: connection | cursor) -> str: ...
    def __add__(self, other: Composable) -> Composed: ...
    def __mul__(self, n: int) -> Composed: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...

class Composed(Composable):
    def __init__(self, seq: Iterable[Composable]) -> None: ...
    @property
    def seq(self) -> list[Composable]: ...
    def __iter__(self) -> Iterator[Composable]: ...
    def __add__(self, other: Composable) -> Composed: ...
    def join(self, joiner: str | SQL) -> Composed: ...

class SQL(Composable):
    def __init__(self, string: str) -> None: ...
    @property
    def string(self) -> str: ...
    def format(self, *args: Composable, **kwargs: Composable) -> Composed: ...
    def join(self, seq: Iterable[Composable]) -> Composed: ...

class Identifier(Composable):
    def __init__(self, *strings: str) -> None: ...
    @property
    def strings(self) -> tuple[str, ...]: ...
    @property
    def string(self) -> str: ...

class Literal(Composable, Generic[_T]):
    def __init__(self, wrapped: _T) -> None: ...
    @property
    def wrapped(self) -> _T: ...

class Placeholder(Composable):
    def __init__(self, name: str | None = None) -> None: ...
    @property
    def name(self) -> str | None: ...

NULL: SQL
DEFAULT: SQL



from typing import Any

class Behavior:
    name: str
    description: str
    versionString: str
    knownChildren: Any
    quotedPrintable: bool
    defaultBehavior: Any
    hasNative: bool
    isComponent: bool
    allowGroup: bool
    forceUTC: bool
    sortFirst: Any
    @classmethod
    def validate(cls, obj, raiseException: bool = False, complainUnrecognized: bool = False): ...
    @classmethod
    def lineValidate(cls, line, raiseException, complainUnrecognized): ...
    @classmethod
    def decode(cls, line) -> None: ...
    @classmethod
    def encode(cls, line) -> None: ...
    @classmethod
    def transformToNative(cls, obj): ...
    @classmethod
    def transformFromNative(cls, obj) -> None: ...
    @classmethod
    def generateImplicitParameters(cls, obj) -> None: ...
    @classmethod
    def serialize(cls, obj, buf, lineLength, validate: bool = True): ...
    @classmethod
    def valueRepr(cls, line): ...



import os
import sys
from _typeshed import FileDescriptor, Incomplete, ReadableBuffer
from collections.abc import Callable
from typing import Literal

def tp_read(fd: FileDescriptor, n: int) -> bytes: ...
def tp_write(fd: FileDescriptor, buf: ReadableBuffer) -> int: ...

if sys.platform != "win32":
    def make_nonblocking(fd: FileDescriptor) -> Literal[True] | None: ...
    def nb_read(fd: FileDescriptor, n: int) -> bytes: ...
    def nb_write(fd: FileDescriptor, buf: ReadableBuffer) -> int: ...
    fork = os.fork
    forkpty = os.forkpty
    def fork_gevent() -> int: ...
    def forkpty_gevent() -> tuple[int, int]: ...
    waitpid = os.waitpid
    def fork_and_watch(
        callback: Incomplete | None = None, loop: Incomplete | None = None, ref: bool = False, fork: Callable[[], int] = ...
    ) -> int: ...
    def forkpty_and_watch(
        callback: Incomplete | None = None,
        loop: Incomplete | None = None,
        ref: bool = False,
        forkpty: Callable[[], tuple[int, int]] = ...,
    ) -> tuple[int, int]: ...

    posix_spawn = os.posix_spawn
    posix_spawnp = os.posix_spawnp



from _typeshed import StrOrBytesPath

from ._pygit2 import Oid
from .repository import BaseRepository

class PackBuilder:
    def __init__(self, repo: BaseRepository) -> None: ...
    def __del__(self) -> None: ...
    def __len__(self) -> int: ...
    def add(self, oid: Oid) -> None: ...
    def add_recur(self, oid: Oid) -> None: ...
    def set_threads(self, n_threads: int) -> int: ...
    def write(self, path: StrOrBytesPath | None = None) -> None: ...
    @property
    def written_objects_count(self) -> int: ...



import serial

class RS485Settings:
    rts_level_for_tx: bool
    rts_level_for_rx: bool
    loopback: bool
    delay_before_tx: float | None
    delay_before_rx: float | None
    def __init__(
        self,
        rts_level_for_tx: bool = True,
        rts_level_for_rx: bool = False,
        loopback: bool = False,
        delay_before_tx: float | None = None,
        delay_before_rx: float | None = None,
    ) -> None: ...

class RS485(serial.Serial): ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def triadic_census(G, nodelist: Incomplete | None = None): ...
@_dispatch
def is_triad(G): ...
@_dispatch
def all_triplets(G): ...
@_dispatch
def all_triads(G) -> Generator[Incomplete, None, None]: ...
@_dispatch
def triads_by_type(G): ...
@_dispatch
def triad_type(G): ...
@_dispatch
def random_triad(G, seed: Incomplete | None = None): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def resource_allocation_index(G, ebunch: Incomplete | None = None): ...
@_dispatch
def jaccard_coefficient(G, ebunch: Incomplete | None = None): ...
@_dispatch
def adamic_adar_index(G, ebunch: Incomplete | None = None): ...
@_dispatch
def common_neighbor_centrality(G, ebunch: Incomplete | None = None, alpha: float = 0.8): ...
@_dispatch
def preferential_attachment(G, ebunch: Incomplete | None = None): ...
@_dispatch
def cn_soundarajan_hopcroft(G, ebunch: Incomplete | None = None, community: str = "community"): ...
@_dispatch
def ra_index_soundarajan_hopcroft(G, ebunch: Incomplete | None = None, community: str = "community"): ...
@_dispatch
def within_inter_cluster(G, ebunch: Incomplete | None = None, delta: float = 0.001, community: str = "community"): ...



from _typeshed import Incomplete

from hvac.api.vault_api_base import VaultApiBase

DEFAULT_MOUNT_POINT: str

class KvV1(VaultApiBase):
    def read_secret(self, path, mount_point="secret"): ...
    def list_secrets(self, path, mount_point="secret"): ...
    def create_or_update_secret(self, path, secret, method: Incomplete | None = None, mount_point="secret"): ...
    def delete_secret(self, path, mount_point="secret"): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class LegacyAuthorizationsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_legacy_authorizations_id(self, auth_id, **kwargs): ...
    def delete_legacy_authorizations_id_with_http_info(self, auth_id, **kwargs): ...
    async def delete_legacy_authorizations_id_async(self, auth_id, **kwargs): ...
    def get_legacy_authorizations(self, **kwargs): ...
    def get_legacy_authorizations_with_http_info(self, **kwargs): ...
    async def get_legacy_authorizations_async(self, **kwargs): ...
    def get_legacy_authorizations_id(self, auth_id, **kwargs): ...
    def get_legacy_authorizations_id_with_http_info(self, auth_id, **kwargs): ...
    async def get_legacy_authorizations_id_async(self, auth_id, **kwargs): ...
    def patch_legacy_authorizations_id(self, auth_id, authorization_update_request, **kwargs): ...
    def patch_legacy_authorizations_id_with_http_info(self, auth_id, authorization_update_request, **kwargs): ...
    async def patch_legacy_authorizations_id_async(self, auth_id, authorization_update_request, **kwargs): ...
    def post_legacy_authorizations(self, legacy_authorization_post_request, **kwargs): ...
    def post_legacy_authorizations_with_http_info(self, legacy_authorization_post_request, **kwargs): ...
    async def post_legacy_authorizations_async(self, legacy_authorization_post_request, **kwargs): ...
    def post_legacy_authorizations_id_password(self, auth_id, password_reset_body, **kwargs): ...
    def post_legacy_authorizations_id_password_with_http_info(self, auth_id, password_reset_body, **kwargs): ...
    async def post_legacy_authorizations_id_password_async(self, auth_id, password_reset_body, **kwargs): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def global_reaching_centrality(G, weight: Incomplete | None = None, normalized: bool = True): ...
@_dispatch
def local_reaching_centrality(
    G, v, paths: Incomplete | None = None, weight: Incomplete | None = None, normalized: bool = True
): ...



from _typeshed import ConvertibleToInt, Incomplete
from typing import ClassVar, Literal, overload

from openpyxl.descriptors.base import Bool, Integer, String, _ConvertibleToBool
from openpyxl.descriptors.serialisable import Serialisable

class CellSmartTagPr(Serialisable):
    tagname: ClassVar[str]
    key: String[Literal[False]]
    val: String[Literal[False]]
    def __init__(self, key: str, val: str) -> None: ...

class CellSmartTag(Serialisable):
    tagname: ClassVar[str]
    cellSmartTagPr: Incomplete
    type: Integer[Literal[False]]
    deleted: Bool[Literal[True]]
    xmlBased: Bool[Literal[True]]
    __elements__: ClassVar[tuple[str, ...]]
    @overload
    def __init__(
        self,
        cellSmartTagPr=(),
        *,
        type: ConvertibleToInt,
        deleted: _ConvertibleToBool | None = False,
        xmlBased: _ConvertibleToBool | None = False,
    ) -> None: ...
    @overload
    def __init__(
        self,
        cellSmartTagPr,
        type: ConvertibleToInt,
        deleted: _ConvertibleToBool | None = False,
        xmlBased: _ConvertibleToBool | None = False,
    ) -> None: ...

class CellSmartTags(Serialisable):
    tagname: ClassVar[str]
    cellSmartTag: Incomplete
    r: String[Literal[False]]
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(self, cellSmartTag, r: str) -> None: ...

class SmartTags(Serialisable):
    tagname: ClassVar[str]
    cellSmartTags: Incomplete
    __elements__: ClassVar[tuple[str, ...]]
    def __init__(self, cellSmartTags=()) -> None: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import IslamoWesternCalendar

class Nigeria(IslamoWesternCalendar):
    include_labour_day: ClassVar[bool]
    labour_day_label: ClassVar[str]
    include_good_friday: ClassVar[bool]
    include_easter_monday: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    include_eid_al_fitr: ClassVar[bool]
    include_day_of_sacrifice: ClassVar[bool]
    shift_sunday_holidays: ClassVar[bool]
    shift_new_years_day: ClassVar[bool]
    WEEKEND_DAYS: Incomplete
    FIXED_HOLIDAYS: Incomplete
    def get_fixed_holidays(self, year): ...



from braintree.dispute_details.evidence import DisputeEvidence as DisputeEvidence
from braintree.dispute_details.paypal_message import DisputePayPalMessage as DisputePayPalMessage
from braintree.dispute_details.status_history import DisputeStatusHistory as DisputeStatusHistory



from _typeshed import Incomplete

class XYGeom:
    LINE: str
    STEP: str
    STACKED: str
    BAR: str
    MONOTONEX: str
    STEPBEFORE: str
    STEPAFTER: str
    openapi_types: Incomplete
    attribute_map: Incomplete
    def __init__(self) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from . import isomorphvf2 as vf2

__all__ = ["GraphMatcher", "DiGraphMatcher", "MultiGraphMatcher", "MultiDiGraphMatcher"]

class GraphMatcher(vf2.GraphMatcher):
    node_match: Incomplete
    edge_match: Incomplete
    G1_adj: Incomplete
    G2_adj: Incomplete
    def __init__(self, G1, G2, node_match: Incomplete | None = None, edge_match: Incomplete | None = None) -> None: ...
    semantic_feasibility: Incomplete

class DiGraphMatcher(vf2.DiGraphMatcher):
    node_match: Incomplete
    edge_match: Incomplete
    G1_adj: Incomplete
    G2_adj: Incomplete
    def __init__(self, G1, G2, node_match: Incomplete | None = None, edge_match: Incomplete | None = None) -> None: ...
    def semantic_feasibility(self, G1_node, G2_node): ...

class MultiGraphMatcher(GraphMatcher): ...
class MultiDiGraphMatcher(DiGraphMatcher): ...



from _typeshed import Incomplete
from collections.abc import Callable
from dataclasses import dataclass
from typing import ClassVar

from pandas import DataFrame
from seaborn._core.groupby import GroupBy
from seaborn._core.scales import Scale
from seaborn._core.typing import Default

default: Default

@dataclass
class Move:
    group_by_orient: ClassVar[bool]
    def __call__(self, data: DataFrame, groupby: GroupBy, orient: str, scales: dict[str, Scale]) -> DataFrame: ...

@dataclass
class Jitter(Move):
    width: float | Default = ...
    x: float = 0
    y: float = 0
    seed: int | None = None

@dataclass
class Dodge(Move):
    empty: str = "keep"
    gap: float = 0
    by: list[str] | None = None

@dataclass
class Stack(Move): ...

@dataclass
class Shift(Move):
    x: float = 0
    y: float = 0

@dataclass
class Norm(Move):
    func: Callable[..., Incomplete] | str = "max"
    where: str | None = None
    by: list[str] | None = None
    percent: bool = False



from _typeshed import Incomplete, Unused
from abc import abstractmethod

from pyasn1.type.base import Asn1Type
from pyasn1.type.tag import TagSet

__all__ = ["Encoder", "encode"]

class AbstractItemEncoder:
    supportIndefLenMode: bool
    eooIntegerSubstrate: tuple[int, int]
    eooOctetsSubstrate: bytes
    def encodeTag(self, singleTag, isConstructed): ...
    def encodeLength(self, length, defMode): ...
    @abstractmethod
    def encodeValue(self, value, asn1Spec, encodeFun, **options) -> None: ...
    def encode(self, value, asn1Spec: Asn1Type | None = None, encodeFun: Incomplete | None = None, **options): ...

class EndOfOctetsEncoder(AbstractItemEncoder):
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class BooleanEncoder(AbstractItemEncoder):
    supportIndefLenMode: bool
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class IntegerEncoder(AbstractItemEncoder):
    supportIndefLenMode: bool
    supportCompactZero: bool
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class BitStringEncoder(AbstractItemEncoder):
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class OctetStringEncoder(AbstractItemEncoder):
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class NullEncoder(AbstractItemEncoder):
    supportIndefLenMode: bool
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class ObjectIdentifierEncoder(AbstractItemEncoder):
    supportIndefLenMode: bool
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class RealEncoder(AbstractItemEncoder):
    supportIndefLenMode: bool
    binEncBase: int
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class SequenceEncoder(AbstractItemEncoder):
    omitEmptyOptionals: bool
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class SequenceOfEncoder(AbstractItemEncoder):
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class ChoiceEncoder(AbstractItemEncoder):
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

class AnyEncoder(OctetStringEncoder):
    def encodeValue(self, value, asn1Spec, encodeFun, **options): ...

TAG_MAP: dict[TagSet, AbstractItemEncoder]
TYPE_MAP: dict[int, AbstractItemEncoder]
# deprecated aliases
tagMap = TAG_MAP
typeMap = TYPE_MAP

class SingleItemEncoder:
    fixedDefLengthMode: bool | None
    fixedChunkSize: int | None
    TAG_MAP: dict[TagSet, AbstractItemEncoder]
    TYPE_MAP: dict[int, AbstractItemEncoder]

    def __init__(self, tagMap=..., typeMap=..., **ignored: Unused) -> None: ...
    def __call__(self, value, asn1Spec: Asn1Type | None = None, **options): ...

class Encoder:
    SINGLE_ITEM_ENCODER: type[SingleItemEncoder]

    def __init__(self, tagMap=..., typeMap=..., **options: Unused) -> None: ...
    def __call__(self, pyObject, asn1Spec: Asn1Type | None = None, **options): ...

encode: Encoder



from _typeshed import Unused
from collections.abc import Callable, Sequence
from typing import Any, Literal, TypeVar
from typing_extensions import deprecated

from matplotlib.typing import ColorType

__all__ = [
    "set_theme",
    "set",
    "reset_defaults",
    "reset_orig",
    "axes_style",
    "set_style",
    "plotting_context",
    "set_context",
    "set_palette",
]

_KT = TypeVar("_KT")
_VT = TypeVar("_VT")
_F = TypeVar("_F", bound=Callable[..., Any])

def set_theme(
    context: Literal["paper", "notebook", "talk", "poster"] | dict[str, Any] = "notebook",
    style: Literal["white", "dark", "whitegrid", "darkgrid", "ticks"] | dict[str, Any] = "darkgrid",
    palette: str | Sequence[ColorType] | None = "deep",
    font: str = "sans-serif",
    font_scale: float = 1,
    color_codes: bool = True,
    rc: dict[str, Any] | None = None,
) -> None: ...
@deprecated("Function `set` is deprecated in favor of `set_theme`")
def set(
    context: Literal["paper", "notebook", "talk", "poster"] | dict[str, Any] = "notebook",
    style: Literal["white", "dark", "whitegrid", "darkgrid", "ticks"] | dict[str, Any] = "darkgrid",
    palette: str | Sequence[ColorType] | None = "deep",
    font: str = "sans-serif",
    font_scale: float = 1,
    color_codes: bool = True,
    rc: dict[str, Any] | None = None,
) -> None: ...
def reset_defaults() -> None: ...
def reset_orig() -> None: ...
def axes_style(
    style: Literal["white", "dark", "whitegrid", "darkgrid", "ticks"] | dict[str, Any] | None = None,
    rc: dict[str, Any] | None = None,
) -> _AxesStyle[str, Any]: ...
def set_style(
    style: Literal["white", "dark", "whitegrid", "darkgrid", "ticks"] | dict[str, Any] | None = None,
    rc: dict[str, Any] | None = None,
) -> None: ...
def plotting_context(
    context: Literal["paper", "notebook", "talk", "poster"] | dict[str, Any] | None = None,
    font_scale: float = 1,
    rc: dict[str, Any] | None = None,
) -> _PlottingContext[str, Any]: ...
def set_context(
    context: Literal["paper", "notebook", "talk", "poster"] | dict[str, Any] | None = None,
    font_scale: float = 1,
    rc: dict[str, Any] | None = None,
) -> None: ...

class _RCAesthetics(dict[_KT, _VT]):
    def __enter__(self) -> None: ...
    def __exit__(self, exc_type: Unused, exc_value: Unused, exc_tb: Unused) -> None: ...
    def __call__(self, func: _F) -> _F: ...

class _AxesStyle(_RCAesthetics[_KT, _VT]): ...
class _PlottingContext(_RCAesthetics[_KT, _VT]): ...

def set_palette(
    palette: str | Sequence[ColorType] | None, n_colors: int | None = None, desat: float | None = None, color_codes: bool = False
) -> None: ...



import threading
from _typeshed import Incomplete

# Not bothering with types here as lxml support is supposed to be dropped in a future version
# of defusedxml

LXML3: Incomplete
__origin__: str
tostring: Incomplete

# Should be imported from lxml.etree.ElementBase, but lxml lacks types
class _ElementBase: ...

class RestrictedElement(_ElementBase):
    blacklist: Incomplete
    def __iter__(self): ...
    def iterchildren(self, tag: Incomplete | None = ..., reversed: bool = ...): ...
    def iter(self, tag: Incomplete | None = ..., *tags): ...
    def iterdescendants(self, tag: Incomplete | None = ..., *tags): ...
    def itersiblings(self, tag: Incomplete | None = ..., preceding: bool = ...): ...
    def getchildren(self): ...
    def getiterator(self, tag: Incomplete | None = ...): ...

class GlobalParserTLS(threading.local):
    parser_config: Incomplete
    element_class: Incomplete
    def createDefaultParser(self): ...
    def setDefaultParser(self, parser) -> None: ...
    def getDefaultParser(self): ...

getDefaultParser: Incomplete

def check_docinfo(elementtree, forbid_dtd: bool = ..., forbid_entities: bool = ...) -> None: ...
def parse(
    source,
    parser: Incomplete | None = ...,
    base_url: Incomplete | None = ...,
    forbid_dtd: bool = ...,
    forbid_entities: bool = ...,
): ...
def fromstring(
    text, parser: Incomplete | None = ..., base_url: Incomplete | None = ..., forbid_dtd: bool = ..., forbid_entities: bool = ...
): ...

XML = fromstring

def iterparse(*args, **kwargs) -> None: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import IslamicCalendar, OrthodoxCalendar

class Kazakhstan(OrthodoxCalendar, IslamicCalendar):
    include_christmas: ClassVar[bool]
    include_christmas_eve: ClassVar[bool]
    include_new_years_day: ClassVar[bool]
    include_orthodox_christmas: ClassVar[bool]
    include_epiphany: ClassVar[bool]
    include_good_friday: ClassVar[bool]
    include_easter_saturday: ClassVar[bool]
    include_easter_sunday: ClassVar[bool]
    include_easter_monday: ClassVar[bool]
    include_prophet_birthday: ClassVar[bool]
    include_day_after_prophet_birthday: ClassVar[bool]
    include_start_ramadan: ClassVar[bool]
    include_eid_al_fitr: ClassVar[bool]
    length_eid_al_fitr: int
    include_eid_al_adha: ClassVar[bool]
    length_eid_al_adha: int
    include_day_of_sacrifice: ClassVar[bool]
    day_of_sacrifice_label: ClassVar[str]
    include_islamic_new_year: ClassVar[bool]
    include_laylat_al_qadr: ClassVar[bool]
    include_nuzul_al_quran: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
    def get_fixed_holidays(self, year): ...
    def get_variable_days(self, year): ...



from aws_xray_sdk.core.utils.search_pattern import wildcard_match as wildcard_match

from ...exceptions.exceptions import InvalidSamplingManifestError as InvalidSamplingManifestError
from .reservoir import Reservoir as Reservoir

class SamplingRule:
    FIXED_TARGET: str
    RATE: str
    HOST: str
    METHOD: str
    PATH: str
    SERVICE_NAME: str
    def __init__(self, rule_dict, version: int = 2, default: bool = False) -> None: ...
    def applies(self, host, method, path): ...
    @property
    def fixed_target(self): ...
    @property
    def rate(self): ...
    @property
    def host(self): ...
    @property
    def method(self): ...
    @property
    def path(self): ...
    @property
    def reservoir(self): ...
    @property
    def version(self): ...



import types
from _typeshed import Incomplete

__all__ = ["attach", "_lazy_import"]

def attach(module_name, submodules: Incomplete | None = None, submod_attrs: Incomplete | None = None): ...

class DelayedImportErrorModule(types.ModuleType):
    def __init__(self, frame_data, *args, **kwargs) -> None: ...
    def __getattr__(self, x) -> None: ...

def _lazy_import(fullname) -> types.ModuleType | DelayedImportErrorModule: ...



from collections.abc import Generator
from typing import TextIO

import serial

def sixteen(data: bytes) -> Generator[tuple[str, str] | tuple[None, None], None, None]: ...
def hexdump(data: bytes) -> Generator[tuple[int, str], None, None]: ...

class _Formatter:
    def rx(self, data: bytes) -> None: ...
    def tx(self, data: bytes) -> None: ...
    def control(self, name: str, value: str) -> None: ...

class FormatRaw(_Formatter):
    output: TextIO
    color: bool
    rx_color: str
    tx_color: str
    def __init__(self, output: TextIO, color: bool) -> None: ...

class FormatHexdump(_Formatter):
    start_time: float
    output: TextIO
    color: bool
    rx_color: str
    tx_color: str
    control_color: str
    def __init__(self, output: TextIO, color: bool) -> None: ...
    def write_line(self, timestamp: float, label: str, value: str, value2: str = "") -> None: ...

class Serial(serial.Serial):
    formatter: FormatRaw | FormatHexdump | None
    show_all: bool
    def from_url(self, url: str) -> str: ...
